# Form implementation generated from reading ui file 'DragonLog_Settings.ui'
#
# Created by: PyQt6 UI code generator 6.9.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(450, 550)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Dialog.sizePolicy().hasHeightForWidth())
        Dialog.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Dialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tabWidget = QtWidgets.QTabWidget(parent=Dialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setMinimumSize(QtCore.QSize(0, 450))
        self.tabWidget.setObjectName("tabWidget")
        self.station = QtWidgets.QWidget()
        self.station.setObjectName("station")
        self.formLayout = QtWidgets.QFormLayout(self.station)
        self.formLayout.setObjectName("formLayout")
        self.label = QtWidgets.QLabel(parent=self.station)
        self.label.setObjectName("label")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label)
        self.callsignLineEdit = QtWidgets.QLineEdit(parent=self.station)
        self.callsignLineEdit.setObjectName("callsignLineEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.callsignLineEdit)
        self.label_2 = QtWidgets.QLabel(parent=self.station)
        self.label_2.setObjectName("label_2")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_2)
        self.nameLineEdit = QtWidgets.QLineEdit(parent=self.station)
        self.nameLineEdit.setObjectName("nameLineEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.nameLineEdit)
        self.label_3 = QtWidgets.QLabel(parent=self.station)
        self.label_3.setObjectName("label_3")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_3)
        spacerItem = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Minimum)
        self.formLayout.setItem(3, QtWidgets.QFormLayout.ItemRole.FieldRole, spacerItem)
        self.label_5 = QtWidgets.QLabel(parent=self.station)
        self.label_5.setObjectName("label_5")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_5)
        self.radioComboBox = QtWidgets.QComboBox(parent=self.station)
        self.radioComboBox.setObjectName("radioComboBox")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.ItemRole.FieldRole, self.radioComboBox)
        self.label_6 = QtWidgets.QLabel(parent=self.station)
        self.label_6.setObjectName("label_6")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_6)
        self.antennaComboBox = QtWidgets.QComboBox(parent=self.station)
        self.antennaComboBox.setObjectName("antennaComboBox")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.ItemRole.FieldRole, self.antennaComboBox)
        spacerItem1 = QtWidgets.QSpacerItem(20, 500, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.formLayout.setItem(6, QtWidgets.QFormLayout.ItemRole.FieldRole, spacerItem1)
        self.qthComboBox = QtWidgets.QComboBox(parent=self.station)
        self.qthComboBox.setObjectName("qthComboBox")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.qthComboBox)
        self.tabWidget.addTab(self.station, "")
        self.listings = QtWidgets.QWidget()
        self.listings.setObjectName("listings")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.listings)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.listingsWidget = QtWidgets.QWidget(parent=self.listings)
        self.listingsWidget.setObjectName("listingsWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.listingsWidget)
        self.gridLayout.setObjectName("gridLayout")
        self.verticalLayout_12.addWidget(self.listingsWidget)
        self.tabWidget.addTab(self.listings, "")
        self.bands_modes = QtWidgets.QWidget()
        self.bands_modes.setObjectName("bands_modes")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.bands_modes)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.bandsGroupBox = QtWidgets.QGroupBox(parent=self.bands_modes)
        self.bandsGroupBox.setObjectName("bandsGroupBox")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.bandsGroupBox)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout_14.addWidget(self.bandsGroupBox)
        self.modesGroupBox = QtWidgets.QGroupBox(parent=self.bands_modes)
        self.modesGroupBox.setObjectName("modesGroupBox")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.modesGroupBox)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.verticalLayout_14.addWidget(self.modesGroupBox)
        self.tabWidget.addTab(self.bands_modes, "")
        self.cb_station = QtWidgets.QWidget()
        self.cb_station.setObjectName("cb_station")
        self.formLayout_2 = QtWidgets.QFormLayout(self.cb_station)
        self.formLayout_2.setObjectName("formLayout_2")
        self.label_10 = QtWidgets.QLabel(parent=self.cb_station)
        self.label_10.setObjectName("label_10")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_10)
        self.callsignCBLineEdit = QtWidgets.QLineEdit(parent=self.cb_station)
        self.callsignCBLineEdit.setObjectName("callsignCBLineEdit")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.callsignCBLineEdit)
        self.label_9 = QtWidgets.QLabel(parent=self.cb_station)
        self.label_9.setObjectName("label_9")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_9)
        self.radioCBLineEdit = QtWidgets.QLineEdit(parent=self.cb_station)
        self.radioCBLineEdit.setObjectName("radioCBLineEdit")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.radioCBLineEdit)
        self.label_11 = QtWidgets.QLabel(parent=self.cb_station)
        self.label_11.setObjectName("label_11")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_11)
        self.antennaCBLineEdit = QtWidgets.QLineEdit(parent=self.cb_station)
        self.antennaCBLineEdit.setObjectName("antennaCBLineEdit")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.antennaCBLineEdit)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.formLayout_2.setItem(5, QtWidgets.QFormLayout.ItemRole.FieldRole, spacerItem2)
        self.cbDefaultCheckBox = QtWidgets.QCheckBox(parent=self.cb_station)
        self.cbDefaultCheckBox.setObjectName("cbDefaultCheckBox")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.ItemRole.FieldRole, self.cbDefaultCheckBox)
        self.expCBQSOsCheckBox = QtWidgets.QCheckBox(parent=self.cb_station)
        self.expCBQSOsCheckBox.setObjectName("expCBQSOsCheckBox")
        self.formLayout_2.setWidget(4, QtWidgets.QFormLayout.ItemRole.FieldRole, self.expCBQSOsCheckBox)
        self.tabWidget.addTab(self.cb_station, "")
        self.cat = QtWidgets.QWidget()
        self.cat.setObjectName("cat")
        self.formLayout_3 = QtWidgets.QFormLayout(self.cat)
        self.formLayout_3.setObjectName("formLayout_3")
        self.rigctldPathLabel = QtWidgets.QLabel(parent=self.cat)
        self.rigctldPathLabel.setObjectName("rigctldPathLabel")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.rigctldPathLabel)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.hamlibPathLineEdit = QtWidgets.QLineEdit(parent=self.cat)
        self.hamlibPathLineEdit.setReadOnly(True)
        self.hamlibPathLineEdit.setObjectName("hamlibPathLineEdit")
        self.horizontalLayout_2.addWidget(self.hamlibPathLineEdit)
        self.hamlibPathToolButton = QtWidgets.QToolButton(parent=self.cat)
        self.hamlibPathToolButton.setObjectName("hamlibPathToolButton")
        self.horizontalLayout_2.addWidget(self.hamlibPathToolButton)
        self.formLayout_3.setLayout(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.horizontalLayout_2)
        self.checkHamlibLabel = QtWidgets.QLabel(parent=self.cat)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
        palette.setBrush(QtGui.QPalette.ColorGroup.Active, QtGui.QPalette.ColorRole.WindowText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 0, 0))
        brush.setStyle(QtCore.Qt.BrushStyle.SolidPattern)
        palette.setBrush(QtGui.QPalette.ColorGroup.Inactive, QtGui.QPalette.ColorRole.WindowText, brush)
        self.checkHamlibLabel.setPalette(palette)
        self.checkHamlibLabel.setText("")
        self.checkHamlibLabel.setObjectName("checkHamlibLabel")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.checkHamlibLabel)
        self.label_12 = QtWidgets.QLabel(parent=self.cat)
        self.label_12.setObjectName("label_12")
        self.formLayout_3.setWidget(3, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_12)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.catInterfaceLineEdit = QtWidgets.QLineEdit(parent=self.cat)
        self.catInterfaceLineEdit.setObjectName("catInterfaceLineEdit")
        self.horizontalLayout_5.addWidget(self.catInterfaceLineEdit)
        self.catBaudComboBox = QtWidgets.QComboBox(parent=self.cat)
        self.catBaudComboBox.setObjectName("catBaudComboBox")
        self.catBaudComboBox.addItem("")
        self.catBaudComboBox.addItem("")
        self.catBaudComboBox.addItem("")
        self.catBaudComboBox.addItem("")
        self.catBaudComboBox.addItem("")
        self.catBaudComboBox.addItem("")
        self.catBaudComboBox.addItem("")
        self.catBaudComboBox.addItem("")
        self.catBaudComboBox.addItem("")
        self.catBaudComboBox.addItem("")
        self.horizontalLayout_5.addWidget(self.catBaudComboBox)
        self.formLayout_3.setLayout(3, QtWidgets.QFormLayout.ItemRole.FieldRole, self.horizontalLayout_5)
        self.label_13 = QtWidgets.QLabel(parent=self.cat)
        self.label_13.setObjectName("label_13")
        self.formLayout_3.setWidget(5, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_13)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.manufacturerComboBox = QtWidgets.QComboBox(parent=self.cat)
        self.manufacturerComboBox.setObjectName("manufacturerComboBox")
        self.horizontalLayout_3.addWidget(self.manufacturerComboBox)
        self.modelComboBox = QtWidgets.QComboBox(parent=self.cat)
        self.modelComboBox.setObjectName("modelComboBox")
        self.horizontalLayout_3.addWidget(self.modelComboBox)
        self.formLayout_3.setLayout(5, QtWidgets.QFormLayout.ItemRole.FieldRole, self.horizontalLayout_3)
        spacerItem3 = QtWidgets.QSpacerItem(20, 1000, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.formLayout_3.setItem(6, QtWidgets.QFormLayout.ItemRole.FieldRole, spacerItem3)
        self.checkHamlibRunLabel = QtWidgets.QLabel(parent=self.cat)
        self.checkHamlibRunLabel.setText("")
        self.checkHamlibRunLabel.setObjectName("checkHamlibRunLabel")
        self.formLayout_3.setWidget(7, QtWidgets.QFormLayout.ItemRole.FieldRole, self.checkHamlibRunLabel)
        self.tabWidget.addTab(self.cat, "")
        self.userinterface = QtWidgets.QWidget()
        self.userinterface.setObjectName("userinterface")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.userinterface)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.groupBox_12 = QtWidgets.QGroupBox(parent=self.userinterface)
        self.groupBox_12.setObjectName("groupBox_12")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout(self.groupBox_12)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.verticalLayout_16 = QtWidgets.QVBoxLayout()
        self.verticalLayout_16.setContentsMargins(-1, 4, -1, -1)
        self.verticalLayout_16.setObjectName("verticalLayout_16")
        self.fontComboBox = QtWidgets.QFontComboBox(parent=self.groupBox_12)
        self.fontComboBox.setObjectName("fontComboBox")
        self.verticalLayout_16.addWidget(self.fontComboBox)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout_16.addItem(spacerItem4)
        self.horizontalLayout_12.addLayout(self.verticalLayout_16)
        self.formLayout_8 = QtWidgets.QFormLayout()
        self.formLayout_8.setObjectName("formLayout_8")
        self.label_14 = QtWidgets.QLabel(parent=self.groupBox_12)
        self.label_14.setObjectName("label_14")
        self.formLayout_8.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_14)
        self.fontSizeSpinBox = QtWidgets.QSpinBox(parent=self.groupBox_12)
        self.fontSizeSpinBox.setMaximumSize(QtCore.QSize(60, 16777215))
        self.fontSizeSpinBox.setMinimum(6)
        self.fontSizeSpinBox.setMaximum(48)
        self.fontSizeSpinBox.setStepType(QtWidgets.QAbstractSpinBox.StepType.AdaptiveDecimalStepType)
        self.fontSizeSpinBox.setProperty("value", 9)
        self.fontSizeSpinBox.setObjectName("fontSizeSpinBox")
        self.formLayout_8.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.fontSizeSpinBox)
        self.label_15 = QtWidgets.QLabel(parent=self.groupBox_12)
        self.label_15.setObjectName("label_15")
        self.formLayout_8.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_15)
        self.qfFontSizeSpinBox = QtWidgets.QSpinBox(parent=self.groupBox_12)
        self.qfFontSizeSpinBox.setMaximumSize(QtCore.QSize(60, 16777215))
        self.qfFontSizeSpinBox.setMinimum(6)
        self.qfFontSizeSpinBox.setMaximum(48)
        self.qfFontSizeSpinBox.setStepType(QtWidgets.QAbstractSpinBox.StepType.AdaptiveDecimalStepType)
        self.qfFontSizeSpinBox.setProperty("value", 9)
        self.qfFontSizeSpinBox.setObjectName("qfFontSizeSpinBox")
        self.formLayout_8.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.qfFontSizeSpinBox)
        self.label_25 = QtWidgets.QLabel(parent=self.groupBox_12)
        self.label_25.setObjectName("label_25")
        self.formLayout_8.setWidget(2, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_25)
        self.ccFontSizeSpinBox = QtWidgets.QSpinBox(parent=self.groupBox_12)
        self.ccFontSizeSpinBox.setMaximumSize(QtCore.QSize(60, 16777215))
        self.ccFontSizeSpinBox.setMinimum(6)
        self.ccFontSizeSpinBox.setMaximum(48)
        self.ccFontSizeSpinBox.setStepType(QtWidgets.QAbstractSpinBox.StepType.AdaptiveDecimalStepType)
        self.ccFontSizeSpinBox.setProperty("value", 9)
        self.ccFontSizeSpinBox.setObjectName("ccFontSizeSpinBox")
        self.formLayout_8.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.ccFontSizeSpinBox)
        self.horizontalLayout_12.addLayout(self.formLayout_8)
        self.verticalLayout_5.addWidget(self.groupBox_12)
        self.groupBox_2 = QtWidgets.QGroupBox(parent=self.userinterface)
        self.groupBox_2.setObjectName("groupBox_2")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.groupBox_2)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout()
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.sortComboBox = QtWidgets.QComboBox(parent=self.groupBox_2)
        self.sortComboBox.setObjectName("sortComboBox")
        self.verticalLayout_11.addWidget(self.sortComboBox)
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout_11.addItem(spacerItem5)
        self.horizontalLayout_8.addLayout(self.verticalLayout_11)
        self.verticalLayout_10 = QtWidgets.QVBoxLayout()
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.sortAscRadioButton = QtWidgets.QRadioButton(parent=self.groupBox_2)
        self.sortAscRadioButton.setChecked(True)
        self.sortAscRadioButton.setObjectName("sortAscRadioButton")
        self.verticalLayout_10.addWidget(self.sortAscRadioButton)
        self.sortDscRadioButton = QtWidgets.QRadioButton(parent=self.groupBox_2)
        self.sortDscRadioButton.setObjectName("sortDscRadioButton")
        self.verticalLayout_10.addWidget(self.sortDscRadioButton)
        self.horizontalLayout_8.addLayout(self.verticalLayout_10)
        self.verticalLayout_5.addWidget(self.groupBox_2)
        self.groupBox_7 = QtWidgets.QGroupBox(parent=self.userinterface)
        self.groupBox_7.setObjectName("groupBox_7")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.groupBox_7)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_20 = QtWidgets.QLabel(parent=self.groupBox_7)
        self.label_20.setObjectName("label_20")
        self.horizontalLayout_9.addWidget(self.label_20)
        self.recentQSOsComboBox = QtWidgets.QComboBox(parent=self.groupBox_7)
        self.recentQSOsComboBox.setObjectName("recentQSOsComboBox")
        self.recentQSOsComboBox.addItem("")
        self.recentQSOsComboBox.addItem("")
        self.recentQSOsComboBox.addItem("")
        self.recentQSOsComboBox.addItem("")
        self.recentQSOsComboBox.addItem("")
        self.horizontalLayout_9.addWidget(self.recentQSOsComboBox)
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem6)
        self.verticalLayout_5.addWidget(self.groupBox_7)
        self.columnsGroupBox = QtWidgets.QGroupBox(parent=self.userinterface)
        self.columnsGroupBox.setObjectName("columnsGroupBox")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.columnsGroupBox)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.verticalLayout_5.addWidget(self.columnsGroupBox)
        self.checkUpdatesCheckBox = QtWidgets.QCheckBox(parent=self.userinterface)
        self.checkUpdatesCheckBox.setChecked(True)
        self.checkUpdatesCheckBox.setObjectName("checkUpdatesCheckBox")
        self.verticalLayout_5.addWidget(self.checkUpdatesCheckBox)
        self.groupBox_8 = QtWidgets.QGroupBox(parent=self.userinterface)
        self.groupBox_8.setObjectName("groupBox_8")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout(self.groupBox_8)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.label_21 = QtWidgets.QLabel(parent=self.groupBox_8)
        self.label_21.setObjectName("label_21")
        self.horizontalLayout_10.addWidget(self.label_21)
        self.logLevelComboBox = QtWidgets.QComboBox(parent=self.groupBox_8)
        self.logLevelComboBox.setCurrentText("Info")
        self.logLevelComboBox.setObjectName("logLevelComboBox")
        self.logLevelComboBox.addItem("")
        self.logLevelComboBox.setItemText(0, "Debug")
        self.logLevelComboBox.addItem("")
        self.logLevelComboBox.setItemText(1, "Info")
        self.logLevelComboBox.addItem("")
        self.logLevelComboBox.setItemText(2, "Warning")
        self.logLevelComboBox.addItem("")
        self.logLevelComboBox.setItemText(3, "Error")
        self.logLevelComboBox.addItem("")
        self.logLevelComboBox.setItemText(4, "Critical")
        self.horizontalLayout_10.addWidget(self.logLevelComboBox)
        self.logToFileCheckBox = QtWidgets.QCheckBox(parent=self.groupBox_8)
        self.logToFileCheckBox.setObjectName("logToFileCheckBox")
        self.horizontalLayout_10.addWidget(self.logToFileCheckBox)
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem7)
        self.verticalLayout_5.addWidget(self.groupBox_8)
        spacerItem8 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout_5.addItem(spacerItem8)
        self.horizontalLayout_6.addLayout(self.verticalLayout_5)
        self.tabWidget.addTab(self.userinterface, "")
        self.dxspots = QtWidgets.QWidget()
        self.dxspots.setObjectName("dxspots")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.dxspots)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBox = QtWidgets.QGroupBox(parent=self.dxspots)
        self.groupBox.setObjectName("groupBox")
        self.formLayout_7 = QtWidgets.QFormLayout(self.groupBox)
        self.formLayout_7.setObjectName("formLayout_7")
        self.label_4 = QtWidgets.QLabel(parent=self.groupBox)
        self.label_4.setObjectName("label_4")
        self.formLayout_7.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_4)
        self.dxAddrLineEdit = QtWidgets.QLineEdit(parent=self.groupBox)
        self.dxAddrLineEdit.setObjectName("dxAddrLineEdit")
        self.formLayout_7.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.dxAddrLineEdit)
        self.label_7 = QtWidgets.QLabel(parent=self.groupBox)
        self.label_7.setObjectName("label_7")
        self.formLayout_7.setWidget(2, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_7)
        self.dxPortSpinBox = QtWidgets.QSpinBox(parent=self.groupBox)
        self.dxPortSpinBox.setMinimum(1)
        self.dxPortSpinBox.setMaximum(65535)
        self.dxPortSpinBox.setStepType(QtWidgets.QAbstractSpinBox.StepType.AdaptiveDecimalStepType)
        self.dxPortSpinBox.setProperty("value", 7300)
        self.dxPortSpinBox.setObjectName("dxPortSpinBox")
        self.formLayout_7.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.dxPortSpinBox)
        self.label_8 = QtWidgets.QLabel(parent=self.groupBox)
        self.label_8.setObjectName("label_8")
        self.formLayout_7.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_8)
        self.dxCallLineEdit = QtWidgets.QLineEdit(parent=self.groupBox)
        self.dxCallLineEdit.setObjectName("dxCallLineEdit")
        self.formLayout_7.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.dxCallLineEdit)
        self.verticalLayout_3.addWidget(self.groupBox)
        self.groupBox_11 = QtWidgets.QGroupBox(parent=self.dxspots)
        self.groupBox_11.setObjectName("groupBox_11")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.groupBox_11)
        self.horizontalLayout_13.setSpacing(0)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.ctyPathLineEdit = QtWidgets.QLineEdit(parent=self.groupBox_11)
        self.ctyPathLineEdit.setObjectName("ctyPathLineEdit")
        self.horizontalLayout_13.addWidget(self.ctyPathLineEdit)
        self.ctyPathToolButton = QtWidgets.QToolButton(parent=self.groupBox_11)
        self.ctyPathToolButton.setObjectName("ctyPathToolButton")
        self.horizontalLayout_13.addWidget(self.ctyPathToolButton)
        self.verticalLayout_3.addWidget(self.groupBox_11)
        spacerItem9 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout_3.addItem(spacerItem9)
        self.tabWidget.addTab(self.dxspots, "")
        self.import_export = QtWidgets.QWidget()
        self.import_export.setObjectName("import_export")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.import_export)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.groupBox_3 = QtWidgets.QGroupBox(parent=self.import_export)
        self.groupBox_3.setObjectName("groupBox_3")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.groupBox_3)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.expOwnNotesADIFCheckBox = QtWidgets.QCheckBox(parent=self.groupBox_3)
        self.expOwnNotesADIFCheckBox.setObjectName("expOwnNotesADIFCheckBox")
        self.verticalLayout_7.addWidget(self.expOwnNotesADIFCheckBox)
        self.expRecentOnlyCheckBox = QtWidgets.QCheckBox(parent=self.groupBox_3)
        self.expRecentOnlyCheckBox.setObjectName("expRecentOnlyCheckBox")
        self.verticalLayout_7.addWidget(self.expRecentOnlyCheckBox)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_26 = QtWidgets.QLabel(parent=self.groupBox_3)
        self.label_26.setObjectName("label_26")
        self.horizontalLayout_4.addWidget(self.label_26)
        self.csvDelimiterComboBox = QtWidgets.QComboBox(parent=self.groupBox_3)
        self.csvDelimiterComboBox.setObjectName("csvDelimiterComboBox")
        self.csvDelimiterComboBox.addItem("")
        self.csvDelimiterComboBox.addItem("")
        self.horizontalLayout_4.addWidget(self.csvDelimiterComboBox)
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem10)
        self.verticalLayout_7.addLayout(self.horizontalLayout_4)
        self.verticalLayout_2.addWidget(self.groupBox_3)
        self.groupBox_9 = QtWidgets.QGroupBox(parent=self.import_export)
        self.groupBox_9.setObjectName("groupBox_9")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.groupBox_9)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.useCfgIDImportCheckBox = QtWidgets.QCheckBox(parent=self.groupBox_9)
        self.useCfgIDImportCheckBox.setObjectName("useCfgIDImportCheckBox")
        self.verticalLayout_13.addWidget(self.useCfgIDImportCheckBox)
        self.useCfgStationImportCheckBox = QtWidgets.QCheckBox(parent=self.groupBox_9)
        self.useCfgStationImportCheckBox.setObjectName("useCfgStationImportCheckBox")
        self.verticalLayout_13.addWidget(self.useCfgStationImportCheckBox)
        self.verticalLayout_2.addWidget(self.groupBox_9)
        self.groupBox_4 = QtWidgets.QGroupBox(parent=self.import_export)
        self.groupBox_4.setObjectName("groupBox_4")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.groupBox_4)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.useCfgIDWatchCheckBox = QtWidgets.QCheckBox(parent=self.groupBox_4)
        self.useCfgIDWatchCheckBox.setObjectName("useCfgIDWatchCheckBox")
        self.verticalLayout_8.addWidget(self.useCfgIDWatchCheckBox)
        self.useCfgStationWatchCheckBox = QtWidgets.QCheckBox(parent=self.groupBox_4)
        self.useCfgStationWatchCheckBox.setObjectName("useCfgStationWatchCheckBox")
        self.verticalLayout_8.addWidget(self.useCfgStationWatchCheckBox)
        self.verticalLayout_2.addWidget(self.groupBox_4)
        self.groupBox_10 = QtWidgets.QGroupBox(parent=self.import_export)
        self.groupBox_10.setObjectName("groupBox_10")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout(self.groupBox_10)
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.useCfgStationCCCheckBox = QtWidgets.QCheckBox(parent=self.groupBox_10)
        self.useCfgStationCCCheckBox.setObjectName("useCfgStationCCCheckBox")
        self.verticalLayout_15.addWidget(self.useCfgStationCCCheckBox)
        self.verticalLayout_2.addWidget(self.groupBox_10)
        spacerItem11 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout_2.addItem(spacerItem11)
        self.tabWidget.addTab(self.import_export, "")
        self.credentials = QtWidgets.QWidget()
        self.credentials.setObjectName("credentials")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.credentials)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.groupBox_5 = QtWidgets.QGroupBox(parent=self.credentials)
        self.groupBox_5.setObjectName("groupBox_5")
        self.formLayout_4 = QtWidgets.QFormLayout(self.groupBox_5)
        self.formLayout_4.setObjectName("formLayout_4")
        self.label_16 = QtWidgets.QLabel(parent=self.groupBox_5)
        self.label_16.setObjectName("label_16")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_16)
        self.callbookUserLineEdit = QtWidgets.QLineEdit(parent=self.groupBox_5)
        self.callbookUserLineEdit.setObjectName("callbookUserLineEdit")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.callbookUserLineEdit)
        self.label_17 = QtWidgets.QLabel(parent=self.groupBox_5)
        self.label_17.setObjectName("label_17")
        self.formLayout_4.setWidget(2, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_17)
        self.callbookPasswdLineEdit = QtWidgets.QLineEdit(parent=self.groupBox_5)
        self.callbookPasswdLineEdit.setEchoMode(QtWidgets.QLineEdit.EchoMode.PasswordEchoOnEdit)
        self.callbookPasswdLineEdit.setObjectName("callbookPasswdLineEdit")
        self.formLayout_4.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.callbookPasswdLineEdit)
        self.callbookComboBox = QtWidgets.QComboBox(parent=self.groupBox_5)
        self.callbookComboBox.setObjectName("callbookComboBox")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.callbookComboBox)
        self.label_24 = QtWidgets.QLabel(parent=self.groupBox_5)
        self.label_24.setObjectName("label_24")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_24)
        self.verticalLayout_9.addWidget(self.groupBox_5)
        self.groupBox_6 = QtWidgets.QGroupBox(parent=self.credentials)
        self.groupBox_6.setObjectName("groupBox_6")
        self.formLayout_5 = QtWidgets.QFormLayout(self.groupBox_6)
        self.formLayout_5.setObjectName("formLayout_5")
        self.label_18 = QtWidgets.QLabel(parent=self.groupBox_6)
        self.label_18.setObjectName("label_18")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_18)
        self.eqslUserLineEdit = QtWidgets.QLineEdit(parent=self.groupBox_6)
        self.eqslUserLineEdit.setObjectName("eqslUserLineEdit")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.eqslUserLineEdit)
        self.label_19 = QtWidgets.QLabel(parent=self.groupBox_6)
        self.label_19.setObjectName("label_19")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_19)
        self.eqslPasswdLineEdit = QtWidgets.QLineEdit(parent=self.groupBox_6)
        self.eqslPasswdLineEdit.setEchoMode(QtWidgets.QLineEdit.EchoMode.PasswordEchoOnEdit)
        self.eqslPasswdLineEdit.setObjectName("eqslPasswdLineEdit")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.eqslPasswdLineEdit)
        self.verticalLayout_9.addWidget(self.groupBox_6)
        self.groupBox_81 = QtWidgets.QGroupBox(parent=self.credentials)
        self.groupBox_81.setObjectName("groupBox_81")
        self.formLayout_6 = QtWidgets.QFormLayout(self.groupBox_81)
        self.formLayout_6.setObjectName("formLayout_6")
        self.label_22 = QtWidgets.QLabel(parent=self.groupBox_81)
        self.label_22.setObjectName("label_22")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_22)
        self.lotwUserLineEdit = QtWidgets.QLineEdit(parent=self.groupBox_81)
        self.lotwUserLineEdit.setObjectName("lotwUserLineEdit")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.lotwUserLineEdit)
        self.label_211 = QtWidgets.QLabel(parent=self.groupBox_81)
        self.label_211.setObjectName("label_211")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_211)
        self.lotwPasswdLineEdit = QtWidgets.QLineEdit(parent=self.groupBox_81)
        self.lotwPasswdLineEdit.setEchoMode(QtWidgets.QLineEdit.EchoMode.PasswordEchoOnEdit)
        self.lotwPasswdLineEdit.setObjectName("lotwPasswdLineEdit")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.lotwPasswdLineEdit)
        self.lotwCertPwdCheckBox = QtWidgets.QCheckBox(parent=self.groupBox_81)
        self.lotwCertPwdCheckBox.setObjectName("lotwCertPwdCheckBox")
        self.formLayout_6.setWidget(3, QtWidgets.QFormLayout.ItemRole.FieldRole, self.lotwCertPwdCheckBox)
        self.label_23 = QtWidgets.QLabel(parent=self.groupBox_81)
        self.label_23.setObjectName("label_23")
        self.formLayout_6.setWidget(3, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_23)
        self.line = QtWidgets.QFrame(parent=self.groupBox_81)
        self.line.setFrameShape(QtWidgets.QFrame.Shape.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line.setObjectName("line")
        self.formLayout_6.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.line)
        self.verticalLayout_9.addWidget(self.groupBox_81)
        spacerItem12 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout_9.addItem(spacerItem12)
        self.tabWidget.addTab(self.credentials, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.buttonBox = QtWidgets.QDialogButtonBox(parent=Dialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(Dialog)
        self.tabWidget.setCurrentIndex(0)
        self.logLevelComboBox.setCurrentIndex(1)
        self.buttonBox.accepted.connect(Dialog.accept) # type: ignore
        self.buttonBox.rejected.connect(Dialog.reject) # type: ignore
        self.hamlibPathToolButton.clicked.connect(Dialog.chooseHamlibPath) # type: ignore
        self.manufacturerComboBox.currentTextChanged['QString'].connect(Dialog.mfrChanged) # type: ignore
        self.callsignCBLineEdit.textChanged['QString'].connect(Dialog.callSignCBChanged) # type: ignore
        self.callsignLineEdit.textChanged['QString'].connect(Dialog.callSignChanged) # type: ignore
        self.callsignCBLineEdit.textEdited['QString'].connect(Dialog.callSignCBChanged) # type: ignore
        self.callsignLineEdit.textEdited['QString'].connect(Dialog.callSignChanged) # type: ignore
        self.callbookComboBox.currentTextChanged['QString'].connect(Dialog.callbookSelected) # type: ignore
        self.ctyPathToolButton.clicked.connect(Dialog.chooseCtyDataFile) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Settings"))
        self.label.setText(_translate("Dialog", "Call sign"))
        self.label_2.setText(_translate("Dialog", "Name"))
        self.label_3.setText(_translate("Dialog", "QTH (Locator)"))
        self.label_5.setText(_translate("Dialog", "Radio"))
        self.label_6.setText(_translate("Dialog", "Antenna"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.station), _translate("Dialog", "Station"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.listings), _translate("Dialog", "Listings"))
        self.bandsGroupBox.setTitle(_translate("Dialog", "Bands"))
        self.modesGroupBox.setTitle(_translate("Dialog", "Modes"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.bands_modes), _translate("Dialog", "Bands && Modes"))
        self.label_10.setText(_translate("Dialog", "Call sign"))
        self.label_9.setText(_translate("Dialog", "Radio"))
        self.label_11.setText(_translate("Dialog", "Antenna"))
        self.cbDefaultCheckBox.setText(_translate("Dialog", "Select CB band by default"))
        self.expCBQSOsCheckBox.setToolTip(_translate("Dialog", "On import CB QSOs will always be handled"))
        self.expCBQSOsCheckBox.setText(_translate("Dialog", "Export CB QSOs to ADIF"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.cb_station), _translate("Dialog", "CB-Station"))
        self.rigctldPathLabel.setText(_translate("Dialog", "Hamlib rigctld"))
        self.hamlibPathToolButton.setText(_translate("Dialog", "..."))
        self.label_12.setText(_translate("Dialog", "Interface"))
        self.catBaudComboBox.setItemText(0, _translate("Dialog", "128000"))
        self.catBaudComboBox.setItemText(1, _translate("Dialog", "115200"))
        self.catBaudComboBox.setItemText(2, _translate("Dialog", "57600"))
        self.catBaudComboBox.setItemText(3, _translate("Dialog", "38400"))
        self.catBaudComboBox.setItemText(4, _translate("Dialog", "19200"))
        self.catBaudComboBox.setItemText(5, _translate("Dialog", "14400"))
        self.catBaudComboBox.setItemText(6, _translate("Dialog", "9600"))
        self.catBaudComboBox.setItemText(7, _translate("Dialog", "4800"))
        self.catBaudComboBox.setItemText(8, _translate("Dialog", "2400"))
        self.catBaudComboBox.setItemText(9, _translate("Dialog", "1200"))
        self.label_13.setText(_translate("Dialog", "Rig"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.cat), _translate("Dialog", "CAT"))
        self.groupBox_12.setTitle(_translate("Dialog", "Font"))
        self.label_14.setText(_translate("Dialog", "Application font size"))
        self.fontSizeSpinBox.setSuffix(_translate("Dialog", " pt"))
        self.label_15.setText(_translate("Dialog", "QSO form font size"))
        self.qfFontSizeSpinBox.setSuffix(_translate("Dialog", " pt"))
        self.label_25.setText(_translate("Dialog", "Cassiopeia font size"))
        self.ccFontSizeSpinBox.setSuffix(_translate("Dialog", " pt"))
        self.groupBox_2.setTitle(_translate("Dialog", "Sort on column"))
        self.sortAscRadioButton.setText(_translate("Dialog", "Ascending"))
        self.sortDscRadioButton.setText(_translate("Dialog", "Descending"))
        self.groupBox_7.setTitle(_translate("Dialog", "Recent QSOs"))
        self.label_20.setText(_translate("Dialog", "Show QSOs from"))
        self.recentQSOsComboBox.setItemText(0, _translate("Dialog", "Show all"))
        self.recentQSOsComboBox.setItemText(1, _translate("Dialog", "Last week"))
        self.recentQSOsComboBox.setItemText(2, _translate("Dialog", "Last month"))
        self.recentQSOsComboBox.setItemText(3, _translate("Dialog", "Last half year"))
        self.recentQSOsComboBox.setItemText(4, _translate("Dialog", "Last year"))
        self.columnsGroupBox.setTitle(_translate("Dialog", "Show or hide columns"))
        self.checkUpdatesCheckBox.setText(_translate("Dialog", "Check for updates at startup"))
        self.groupBox_8.setToolTip(_translate("Dialog", "Effective after application restart"))
        self.groupBox_8.setTitle(_translate("Dialog", "Logging output"))
        self.label_21.setText(_translate("Dialog", "Level"))
        self.logToFileCheckBox.setText(_translate("Dialog", "Log to file"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.userinterface), _translate("Dialog", "User interface"))
        self.groupBox.setTitle(_translate("Dialog", "DX Cluster"))
        self.label_4.setText(_translate("Dialog", "Address"))
        self.dxAddrLineEdit.setText(_translate("Dialog", "hamqth.com"))
        self.label_7.setText(_translate("Dialog", "Port"))
        self.label_8.setText(_translate("Dialog", "Call"))
        self.groupBox_11.setTitle(_translate("Dialog", "Country Data"))
        self.ctyPathToolButton.setText(_translate("Dialog", "..."))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.dxspots), _translate("Dialog", "Dx Spots"))
        self.groupBox_3.setTitle(_translate("Dialog", "Export"))
        self.expOwnNotesADIFCheckBox.setText(_translate("Dialog", "Export own notes to ADIF"))
        self.expRecentOnlyCheckBox.setToolTip(_translate("Dialog", "See settings page \"User interface\""))
        self.expRecentOnlyCheckBox.setText(_translate("Dialog", "Export only recent QSOs"))
        self.label_26.setText(_translate("Dialog", "CSV delimiter"))
        self.csvDelimiterComboBox.setItemText(0, _translate("Dialog", ","))
        self.csvDelimiterComboBox.setItemText(1, _translate("Dialog", ";"))
        self.groupBox_9.setTitle(_translate("Dialog", "ADIF Import"))
        self.useCfgIDImportCheckBox.setText(_translate("Dialog", "Use configured ID for missing values"))
        self.useCfgStationImportCheckBox.setText(_translate("Dialog", "Use configured Station for missing values"))
        self.groupBox_4.setTitle(_translate("Dialog", "Watch File"))
        self.useCfgIDWatchCheckBox.setText(_translate("Dialog", "Use configured ID for missing values"))
        self.useCfgStationWatchCheckBox.setText(_translate("Dialog", "Use configured Station for missing values"))
        self.groupBox_10.setTitle(_translate("Dialog", "CassiopeiaConsole"))
        self.useCfgStationCCCheckBox.setText(_translate("Dialog", "Use configured Station for missing values"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.import_export), _translate("Dialog", "Import/Export"))
        self.groupBox_5.setTitle(_translate("Dialog", "Callbook"))
        self.label_16.setText(_translate("Dialog", "Username"))
        self.label_17.setText(_translate("Dialog", "Password"))
        self.label_24.setText(_translate("Dialog", "Service"))
        self.groupBox_6.setTitle(_translate("Dialog", "eQSL"))
        self.label_18.setText(_translate("Dialog", "Username"))
        self.label_19.setText(_translate("Dialog", "Password"))
        self.groupBox_81.setTitle(_translate("Dialog", "LoTW"))
        self.label_22.setText(_translate("Dialog", "Username"))
        self.lotwUserLineEdit.setToolTip(_translate("Dialog", "Username for LoTW online account not for the certificate"))
        self.label_211.setText(_translate("Dialog", "Password"))
        self.lotwPasswdLineEdit.setToolTip(_translate("Dialog", "Password for LoTW online account not for the certificate"))
        self.lotwCertPwdCheckBox.setText(_translate("Dialog", "Certificate needs password"))
        self.label_23.setText(_translate("Dialog", "TQSL"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.credentials), _translate("Dialog", "Credentials"))
