# Form implementation generated from reading ui file 'CassiopeiaConsole.ui'
#
# Created by: PyQt6 UI code generator 6.9.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_CassiopeiaConsoleWidget(object):
    def setupUi(self, CassiopeiaConsoleWidget):
        CassiopeiaConsoleWidget.setObjectName("CassiopeiaConsoleWidget")
        CassiopeiaConsoleWidget.resize(800, 227)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(CassiopeiaConsoleWidget.sizePolicy().hasHeightForWidth())
        CassiopeiaConsoleWidget.setSizePolicy(sizePolicy)
        CassiopeiaConsoleWidget.setMinimumSize(QtCore.QSize(800, 0))
        self.verticalLayout = QtWidgets.QVBoxLayout(CassiopeiaConsoleWidget)
        self.verticalLayout.setContentsMargins(-1, 6, -1, 6)
        self.verticalLayout.setSpacing(3)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSpacing(10)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.groupBox_2 = QtWidgets.QGroupBox(parent=CassiopeiaConsoleWidget)
        self.groupBox_2.setStyleSheet("QGroupBox {background-color: rgba(0, 0, 255, 63)}")
        self.groupBox_2.setObjectName("groupBox_2")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.groupBox_2)
        self.horizontalLayout_4.setContentsMargins(6, 0, 6, 3)
        self.horizontalLayout_4.setSpacing(9)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_2 = QtWidgets.QLabel(parent=self.groupBox_2)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_4.addWidget(self.label_2)
        self.myCallLineEdit = QtWidgets.QLineEdit(parent=self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.myCallLineEdit.sizePolicy().hasHeightForWidth())
        self.myCallLineEdit.setSizePolicy(sizePolicy)
        self.myCallLineEdit.setProperty("cssClass", "CCInput")
        self.myCallLineEdit.setObjectName("myCallLineEdit")
        self.horizontalLayout_4.addWidget(self.myCallLineEdit)
        self.line_6 = QtWidgets.QFrame(parent=self.groupBox_2)
        self.line_6.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_6.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_6.setObjectName("line_6")
        self.horizontalLayout_4.addWidget(self.line_6)
        self.label_10 = QtWidgets.QLabel(parent=self.groupBox_2)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_4.addWidget(self.label_10)
        self.myLocLineEdit = QtWidgets.QLineEdit(parent=self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.myLocLineEdit.sizePolicy().hasHeightForWidth())
        self.myLocLineEdit.setSizePolicy(sizePolicy)
        self.myLocLineEdit.setProperty("cssClass", "CCInput")
        self.myLocLineEdit.setObjectName("myLocLineEdit")
        self.horizontalLayout_4.addWidget(self.myLocLineEdit)
        self.line_7 = QtWidgets.QFrame(parent=self.groupBox_2)
        self.line_7.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_7.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_7.setObjectName("line_7")
        self.horizontalLayout_4.addWidget(self.line_7)
        self.label_11 = QtWidgets.QLabel(parent=self.groupBox_2)
        self.label_11.setObjectName("label_11")
        self.horizontalLayout_4.addWidget(self.label_11)
        self.myNameLineEdit = QtWidgets.QLineEdit(parent=self.groupBox_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.myNameLineEdit.sizePolicy().hasHeightForWidth())
        self.myNameLineEdit.setSizePolicy(sizePolicy)
        self.myNameLineEdit.setProperty("cssClass", "CCInput")
        self.myNameLineEdit.setObjectName("myNameLineEdit")
        self.horizontalLayout_4.addWidget(self.myNameLineEdit)
        self.horizontalLayout.addWidget(self.groupBox_2)
        self.groupBox_3 = QtWidgets.QGroupBox(parent=CassiopeiaConsoleWidget)
        self.groupBox_3.setStyleSheet("QGroupBox {background-color: rgba(127, 0, 255, 63)}")
        self.groupBox_3.setObjectName("groupBox_3")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.groupBox_3)
        self.horizontalLayout_8.setContentsMargins(6, 0, 6, 3)
        self.horizontalLayout_8.setSpacing(9)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.label_19 = QtWidgets.QLabel(parent=self.groupBox_3)
        self.label_19.setObjectName("label_19")
        self.horizontalLayout_8.addWidget(self.label_19)
        self.eventComboBox = QtWidgets.QComboBox(parent=self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.eventComboBox.sizePolicy().hasHeightForWidth())
        self.eventComboBox.setSizePolicy(sizePolicy)
        self.eventComboBox.setProperty("cssClass", "CCInput")
        self.eventComboBox.setObjectName("eventComboBox")
        self.eventComboBox.addItem("")
        self.eventComboBox.addItem("")
        self.eventComboBox.addItem("")
        self.horizontalLayout_8.addWidget(self.eventComboBox)
        self.line_15 = QtWidgets.QFrame(parent=self.groupBox_3)
        self.line_15.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_15.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_15.setObjectName("line_15")
        self.horizontalLayout_8.addWidget(self.line_15)
        self.label_21 = QtWidgets.QLabel(parent=self.groupBox_3)
        self.label_21.setObjectName("label_21")
        self.horizontalLayout_8.addWidget(self.label_21)
        self.exchTXLineEdit = QtWidgets.QLineEdit(parent=self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.exchTXLineEdit.sizePolicy().hasHeightForWidth())
        self.exchTXLineEdit.setSizePolicy(sizePolicy)
        self.exchTXLineEdit.setProperty("cssClass", "CCInput")
        self.exchTXLineEdit.setObjectName("exchTXLineEdit")
        self.horizontalLayout_8.addWidget(self.exchTXLineEdit)
        self.label = QtWidgets.QLabel(parent=self.groupBox_3)
        font = QtGui.QFont()
        font.setItalic(True)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.horizontalLayout_8.addWidget(self.label)
        self.line_16 = QtWidgets.QFrame(parent=self.groupBox_3)
        self.line_16.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_16.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_16.setObjectName("line_16")
        self.horizontalLayout_8.addWidget(self.line_16)
        self.label_20 = QtWidgets.QLabel(parent=self.groupBox_3)
        self.label_20.setObjectName("label_20")
        self.horizontalLayout_8.addWidget(self.label_20)
        self.exchRXLineEdit = QtWidgets.QLineEdit(parent=self.groupBox_3)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.exchRXLineEdit.sizePolicy().hasHeightForWidth())
        self.exchRXLineEdit.setSizePolicy(sizePolicy)
        self.exchRXLineEdit.setProperty("cssClass", "CCInput")
        self.exchRXLineEdit.setObjectName("exchRXLineEdit")
        self.horizontalLayout_8.addWidget(self.exchRXLineEdit)
        self.label_6 = QtWidgets.QLabel(parent=self.groupBox_3)
        font = QtGui.QFont()
        font.setItalic(True)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_8.addWidget(self.label_6)
        self.horizontalLayout.addWidget(self.groupBox_3)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.qsoDataGroupBox = QtWidgets.QGroupBox(parent=CassiopeiaConsoleWidget)
        self.qsoDataGroupBox.setStyleSheet("QGroupBox {background-color: rgba(255, 255, 0, 63)}")
        self.qsoDataGroupBox.setObjectName("qsoDataGroupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.qsoDataGroupBox)
        self.verticalLayout_2.setContentsMargins(6, 0, 6, 3)
        self.verticalLayout_2.setSpacing(3)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setSpacing(9)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.dateEdit = QtWidgets.QDateEdit(parent=self.qsoDataGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dateEdit.sizePolicy().hasHeightForWidth())
        self.dateEdit.setSizePolicy(sizePolicy)
        self.dateEdit.setCalendarPopup(True)
        self.dateEdit.setProperty("cssClass", "CCInput")
        self.dateEdit.setObjectName("dateEdit")
        self.horizontalLayout_5.addWidget(self.dateEdit)
        self.label_3 = QtWidgets.QLabel(parent=self.qsoDataGroupBox)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_5.addWidget(self.label_3)
        self.line_3 = QtWidgets.QFrame(parent=self.qsoDataGroupBox)
        self.line_3.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_3.setObjectName("line_3")
        self.horizontalLayout_5.addWidget(self.line_3)
        self.timeEdit = QtWidgets.QTimeEdit(parent=self.qsoDataGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.timeEdit.sizePolicy().hasHeightForWidth())
        self.timeEdit.setSizePolicy(sizePolicy)
        self.timeEdit.setProperty("cssClass", "CCInput")
        self.timeEdit.setObjectName("timeEdit")
        self.horizontalLayout_5.addWidget(self.timeEdit)
        self.label_4 = QtWidgets.QLabel(parent=self.qsoDataGroupBox)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_5.addWidget(self.label_4)
        self.line_2 = QtWidgets.QFrame(parent=self.qsoDataGroupBox)
        self.line_2.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout_5.addWidget(self.line_2)
        self.bandComboBox = QtWidgets.QComboBox(parent=self.qsoDataGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bandComboBox.sizePolicy().hasHeightForWidth())
        self.bandComboBox.setSizePolicy(sizePolicy)
        self.bandComboBox.setProperty("cssClass", "CCInput")
        self.bandComboBox.setObjectName("bandComboBox")
        self.bandComboBox.addItem("")
        self.horizontalLayout_5.addWidget(self.bandComboBox)
        self.line = QtWidgets.QFrame(parent=self.qsoDataGroupBox)
        self.line.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_5.addWidget(self.line)
        self.modeComboBox = QtWidgets.QComboBox(parent=self.qsoDataGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.modeComboBox.sizePolicy().hasHeightForWidth())
        self.modeComboBox.setSizePolicy(sizePolicy)
        self.modeComboBox.setProperty("cssClass", "CCInput")
        self.modeComboBox.setObjectName("modeComboBox")
        self.modeComboBox.addItem("")
        self.horizontalLayout_5.addWidget(self.modeComboBox)
        self.line_4 = QtWidgets.QFrame(parent=self.qsoDataGroupBox)
        self.line_4.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_4.setObjectName("line_4")
        self.horizontalLayout_5.addWidget(self.line_4)
        self.callLineEdit = QtWidgets.QLineEdit(parent=self.qsoDataGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.callLineEdit.sizePolicy().hasHeightForWidth())
        self.callLineEdit.setSizePolicy(sizePolicy)
        self.callLineEdit.setProperty("cssClass", "CCInput")
        self.callLineEdit.setObjectName("callLineEdit")
        self.horizontalLayout_5.addWidget(self.callLineEdit)
        self.line_8 = QtWidgets.QFrame(parent=self.qsoDataGroupBox)
        self.line_8.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_8.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_8.setObjectName("line_8")
        self.horizontalLayout_5.addWidget(self.line_8)
        self.label_9 = QtWidgets.QLabel(parent=self.qsoDataGroupBox)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_5.addWidget(self.label_9)
        self.locLineEdit = QtWidgets.QLineEdit(parent=self.qsoDataGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.locLineEdit.sizePolicy().hasHeightForWidth())
        self.locLineEdit.setSizePolicy(sizePolicy)
        self.locLineEdit.setProperty("cssClass", "CCInput")
        self.locLineEdit.setObjectName("locLineEdit")
        self.horizontalLayout_5.addWidget(self.locLineEdit)
        self.line_9 = QtWidgets.QFrame(parent=self.qsoDataGroupBox)
        self.line_9.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_9.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_9.setObjectName("line_9")
        self.horizontalLayout_5.addWidget(self.line_9)
        self.label_13 = QtWidgets.QLabel(parent=self.qsoDataGroupBox)
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_5.addWidget(self.label_13)
        self.rstTXLineEdit = QtWidgets.QLineEdit(parent=self.qsoDataGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.rstTXLineEdit.sizePolicy().hasHeightForWidth())
        self.rstTXLineEdit.setSizePolicy(sizePolicy)
        self.rstTXLineEdit.setMaximumSize(QtCore.QSize(50, 16777215))
        self.rstTXLineEdit.setProperty("cssClass", "CCInput")
        self.rstTXLineEdit.setObjectName("rstTXLineEdit")
        self.horizontalLayout_5.addWidget(self.rstTXLineEdit)
        self.label_7 = QtWidgets.QLabel(parent=self.qsoDataGroupBox)
        font = QtGui.QFont()
        font.setItalic(True)
        self.label_7.setFont(font)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_5.addWidget(self.label_7)
        self.line_5 = QtWidgets.QFrame(parent=self.qsoDataGroupBox)
        self.line_5.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_5.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_5.setObjectName("line_5")
        self.horizontalLayout_5.addWidget(self.line_5)
        self.label_12 = QtWidgets.QLabel(parent=self.qsoDataGroupBox)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_5.addWidget(self.label_12)
        self.rstRXLineEdit = QtWidgets.QLineEdit(parent=self.qsoDataGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.rstRXLineEdit.sizePolicy().hasHeightForWidth())
        self.rstRXLineEdit.setSizePolicy(sizePolicy)
        self.rstRXLineEdit.setMaximumSize(QtCore.QSize(50, 16777215))
        self.rstRXLineEdit.setProperty("cssClass", "CCInput")
        self.rstRXLineEdit.setObjectName("rstRXLineEdit")
        self.horizontalLayout_5.addWidget(self.rstRXLineEdit)
        self.label_8 = QtWidgets.QLabel(parent=self.qsoDataGroupBox)
        font = QtGui.QFont()
        font.setItalic(True)
        self.label_8.setFont(font)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_5.addWidget(self.label_8)
        self.verticalLayout_2.addLayout(self.horizontalLayout_5)
        self.line_10 = QtWidgets.QFrame(parent=self.qsoDataGroupBox)
        self.line_10.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_10.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_10.setObjectName("line_10")
        self.verticalLayout_2.addWidget(self.line_10)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(9)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_14 = QtWidgets.QLabel(parent=self.qsoDataGroupBox)
        self.label_14.setObjectName("label_14")
        self.horizontalLayout_2.addWidget(self.label_14)
        self.nameLineEdit = QtWidgets.QLineEdit(parent=self.qsoDataGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(2)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.nameLineEdit.sizePolicy().hasHeightForWidth())
        self.nameLineEdit.setSizePolicy(sizePolicy)
        self.nameLineEdit.setMaximumSize(QtCore.QSize(200, 16777215))
        self.nameLineEdit.setProperty("cssClass", "CCInput")
        self.nameLineEdit.setObjectName("nameLineEdit")
        self.horizontalLayout_2.addWidget(self.nameLineEdit)
        self.line_14 = QtWidgets.QFrame(parent=self.qsoDataGroupBox)
        self.line_14.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_14.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_14.setObjectName("line_14")
        self.horizontalLayout_2.addWidget(self.line_14)
        self.freqSpinBox = QtWidgets.QSpinBox(parent=self.qsoDataGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.freqSpinBox.sizePolicy().hasHeightForWidth())
        self.freqSpinBox.setSizePolicy(sizePolicy)
        self.freqSpinBox.setMaximum(999999999)
        self.freqSpinBox.setStepType(QtWidgets.QAbstractSpinBox.StepType.AdaptiveDecimalStepType)
        self.freqSpinBox.setProperty("value", 0)
        self.freqSpinBox.setProperty("cssClass", "CCInput")
        self.freqSpinBox.setObjectName("freqSpinBox")
        self.horizontalLayout_2.addWidget(self.freqSpinBox)
        self.label_16 = QtWidgets.QLabel(parent=self.qsoDataGroupBox)
        self.label_16.setObjectName("label_16")
        self.horizontalLayout_2.addWidget(self.label_16)
        self.line_12 = QtWidgets.QFrame(parent=self.qsoDataGroupBox)
        self.line_12.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_12.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_12.setObjectName("line_12")
        self.horizontalLayout_2.addWidget(self.line_12)
        self.powerSpinBox = QtWidgets.QSpinBox(parent=self.qsoDataGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.powerSpinBox.sizePolicy().hasHeightForWidth())
        self.powerSpinBox.setSizePolicy(sizePolicy)
        self.powerSpinBox.setMinimum(0)
        self.powerSpinBox.setMaximum(9999)
        self.powerSpinBox.setStepType(QtWidgets.QAbstractSpinBox.StepType.AdaptiveDecimalStepType)
        self.powerSpinBox.setProperty("value", 0)
        self.powerSpinBox.setProperty("cssClass", "CCInput")
        self.powerSpinBox.setObjectName("powerSpinBox")
        self.horizontalLayout_2.addWidget(self.powerSpinBox)
        self.label_17 = QtWidgets.QLabel(parent=self.qsoDataGroupBox)
        self.label_17.setObjectName("label_17")
        self.horizontalLayout_2.addWidget(self.label_17)
        self.line_13 = QtWidgets.QFrame(parent=self.qsoDataGroupBox)
        self.line_13.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_13.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_13.setObjectName("line_13")
        self.horizontalLayout_2.addWidget(self.line_13)
        self.label_18 = QtWidgets.QLabel(parent=self.qsoDataGroupBox)
        self.label_18.setObjectName("label_18")
        self.horizontalLayout_2.addWidget(self.label_18)
        self.qslCheckBox = QtWidgets.QCheckBox(parent=self.qsoDataGroupBox)
        font = QtGui.QFont()
        font.setItalic(True)
        self.qslCheckBox.setFont(font)
        self.qslCheckBox.setObjectName("qslCheckBox")
        self.horizontalLayout_2.addWidget(self.qslCheckBox)
        self.line_11 = QtWidgets.QFrame(parent=self.qsoDataGroupBox)
        self.line_11.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_11.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_11.setObjectName("line_11")
        self.horizontalLayout_2.addWidget(self.line_11)
        self.label_15 = QtWidgets.QLabel(parent=self.qsoDataGroupBox)
        self.label_15.setObjectName("label_15")
        self.horizontalLayout_2.addWidget(self.label_15)
        self.commentLineEdit = QtWidgets.QLineEdit(parent=self.qsoDataGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.commentLineEdit.sizePolicy().hasHeightForWidth())
        self.commentLineEdit.setSizePolicy(sizePolicy)
        self.commentLineEdit.setProperty("cssClass", "CCInput")
        self.commentLineEdit.setObjectName("commentLineEdit")
        self.horizontalLayout_2.addWidget(self.commentLineEdit)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.verticalLayout.addWidget(self.qsoDataGroupBox)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setContentsMargins(6, -1, -1, -1)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_5 = QtWidgets.QLabel(parent=CassiopeiaConsoleWidget)
        self.label_5.setStyleSheet("background-color: rgba(0, 255, 0, 0)")
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_7.addWidget(self.label_5)
        self.inputLineEdit = QtWidgets.QLineEdit(parent=CassiopeiaConsoleWidget)
        self.inputLineEdit.setProperty("cssClass", "CCInput")
        self.inputLineEdit.setObjectName("inputLineEdit")
        self.horizontalLayout_7.addWidget(self.inputLineEdit)
        self.clearPushButton = QtWidgets.QPushButton(parent=CassiopeiaConsoleWidget)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("icons:no.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.clearPushButton.setIcon(icon)
        self.clearPushButton.setObjectName("clearPushButton")
        self.horizontalLayout_7.addWidget(self.clearPushButton)
        self.addQSOPushButton = QtWidgets.QPushButton(parent=CassiopeiaConsoleWidget)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("icons:edit_add.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.addQSOPushButton.setIcon(icon1)
        self.addQSOPushButton.setObjectName("addQSOPushButton")
        self.horizontalLayout_7.addWidget(self.addQSOPushButton)
        self.onlineCheckBox = QtWidgets.QCheckBox(parent=CassiopeiaConsoleWidget)
        self.onlineCheckBox.setObjectName("onlineCheckBox")
        self.horizontalLayout_7.addWidget(self.onlineCheckBox)
        self.verticalLayout_4.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setContentsMargins(6, -1, 6, -1)
        self.horizontalLayout_3.setSpacing(9)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.ctyCtyLabel = QtWidgets.QLabel(parent=CassiopeiaConsoleWidget)
        self.ctyCtyLabel.setText("")
        self.ctyCtyLabel.setObjectName("ctyCtyLabel")
        self.horizontalLayout_3.addWidget(self.ctyCtyLabel)
        self.line_18 = QtWidgets.QFrame(parent=CassiopeiaConsoleWidget)
        self.line_18.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_18.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_18.setObjectName("line_18")
        self.horizontalLayout_3.addWidget(self.line_18)
        self.ctyAreaLabel = QtWidgets.QLabel(parent=CassiopeiaConsoleWidget)
        self.ctyAreaLabel.setText("")
        self.ctyAreaLabel.setObjectName("ctyAreaLabel")
        self.horizontalLayout_3.addWidget(self.ctyAreaLabel)
        self.line_17 = QtWidgets.QFrame(parent=CassiopeiaConsoleWidget)
        self.line_17.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_17.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_17.setObjectName("line_17")
        self.horizontalLayout_3.addWidget(self.line_17)
        self.distLabel = QtWidgets.QLabel(parent=CassiopeiaConsoleWidget)
        self.distLabel.setText("")
        self.distLabel.setObjectName("distLabel")
        self.horizontalLayout_3.addWidget(self.distLabel)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.verticalLayout_4.addLayout(self.horizontalLayout_3)
        self.resultWidget = QtWidgets.QWidget(parent=CassiopeiaConsoleWidget)
        self.resultWidget.setStyleSheet("#resultWidget {background-color: rgba(0, 255, 0, 63)}")
        self.resultWidget.setObjectName("resultWidget")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.resultWidget)
        self.verticalLayout_3.setContentsMargins(6, 3, 6, 3)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.resultLabel = QtWidgets.QLabel(parent=self.resultWidget)
        self.resultLabel.setText("")
        self.resultLabel.setWordWrap(True)
        self.resultLabel.setObjectName("resultLabel")
        self.verticalLayout_3.addWidget(self.resultLabel)
        self.verticalLayout_4.addWidget(self.resultWidget)
        self.horizontalLayout_6.addLayout(self.verticalLayout_4)
        self.verticalLayout.addLayout(self.horizontalLayout_6)
        spacerItem1 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout.addItem(spacerItem1)

        self.retranslateUi(CassiopeiaConsoleWidget)
        self.eventComboBox.setCurrentIndex(0)
        self.bandComboBox.setCurrentIndex(0)
        self.modeComboBox.setCurrentIndex(0)
        self.clearPushButton.clicked.connect(CassiopeiaConsoleWidget.clearInput) # type: ignore
        self.inputLineEdit.textEdited['QString'].connect(CassiopeiaConsoleWidget.evaluate) # type: ignore
        self.inputLineEdit.returnPressed.connect(CassiopeiaConsoleWidget.finaliseQSO) # type: ignore
        self.addQSOPushButton.clicked.connect(CassiopeiaConsoleWidget.finaliseQSO) # type: ignore
        self.bandComboBox.currentTextChanged['QString'].connect(CassiopeiaConsoleWidget.bandChanged) # type: ignore
        self.dateEdit.userDateChanged['QDate'].connect(CassiopeiaConsoleWidget.dateChanged) # type: ignore
        self.timeEdit.timeChanged['QTime'].connect(CassiopeiaConsoleWidget.timeChanged) # type: ignore
        self.freqSpinBox.valueChanged['int'].connect(CassiopeiaConsoleWidget.freqChanged) # type: ignore
        self.powerSpinBox.valueChanged['int'].connect(CassiopeiaConsoleWidget.powerChanged) # type: ignore
        self.modeComboBox.currentTextChanged['QString'].connect(CassiopeiaConsoleWidget.modeChanged) # type: ignore
        self.callLineEdit.textEdited['QString'].connect(CassiopeiaConsoleWidget.callChanged) # type: ignore
        self.commentLineEdit.editingFinished.connect(CassiopeiaConsoleWidget.commentChanged) # type: ignore
        self.nameLineEdit.editingFinished.connect(CassiopeiaConsoleWidget.nameChanged) # type: ignore
        self.locLineEdit.editingFinished.connect(CassiopeiaConsoleWidget.locatorChanged) # type: ignore
        self.qslCheckBox.clicked['bool'].connect(CassiopeiaConsoleWidget.qslChanged) # type: ignore
        self.rstRXLineEdit.editingFinished.connect(CassiopeiaConsoleWidget.rstRxChanged) # type: ignore
        self.rstTXLineEdit.editingFinished.connect(CassiopeiaConsoleWidget.rstTxChanged) # type: ignore
        self.eventComboBox.currentTextChanged['QString'].connect(CassiopeiaConsoleWidget.eventChanged) # type: ignore
        self.exchRXLineEdit.editingFinished.connect(CassiopeiaConsoleWidget.exchRxChanged) # type: ignore
        self.exchTXLineEdit.editingFinished.connect(CassiopeiaConsoleWidget.exchTxChanged) # type: ignore
        self.myCallLineEdit.editingFinished.connect(CassiopeiaConsoleWidget.myCallChanged) # type: ignore
        self.myNameLineEdit.editingFinished.connect(CassiopeiaConsoleWidget.myNameChanged) # type: ignore
        self.myLocLineEdit.editingFinished.connect(CassiopeiaConsoleWidget.myLocChanged) # type: ignore
        self.onlineCheckBox.clicked['bool'].connect(CassiopeiaConsoleWidget.onlineChanged) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(CassiopeiaConsoleWidget)
        CassiopeiaConsoleWidget.setTabOrder(self.inputLineEdit, self.myCallLineEdit)
        CassiopeiaConsoleWidget.setTabOrder(self.myCallLineEdit, self.myLocLineEdit)
        CassiopeiaConsoleWidget.setTabOrder(self.myLocLineEdit, self.myNameLineEdit)
        CassiopeiaConsoleWidget.setTabOrder(self.myNameLineEdit, self.exchTXLineEdit)
        CassiopeiaConsoleWidget.setTabOrder(self.exchTXLineEdit, self.exchRXLineEdit)
        CassiopeiaConsoleWidget.setTabOrder(self.exchRXLineEdit, self.callLineEdit)
        CassiopeiaConsoleWidget.setTabOrder(self.callLineEdit, self.locLineEdit)
        CassiopeiaConsoleWidget.setTabOrder(self.locLineEdit, self.rstTXLineEdit)
        CassiopeiaConsoleWidget.setTabOrder(self.rstTXLineEdit, self.nameLineEdit)
        CassiopeiaConsoleWidget.setTabOrder(self.nameLineEdit, self.commentLineEdit)

    def retranslateUi(self, CassiopeiaConsoleWidget):
        _translate = QtCore.QCoreApplication.translate
        CassiopeiaConsoleWidget.setWindowTitle(_translate("CassiopeiaConsoleWidget", "CassiopeiaConsole"))
        self.groupBox_2.setTitle(_translate("CassiopeiaConsoleWidget", "Your Data"))
        self.label_2.setText(_translate("CassiopeiaConsoleWidget", "-c"))
        self.myCallLineEdit.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Your callsign"))
        self.label_10.setText(_translate("CassiopeiaConsoleWidget", "-l"))
        self.myLocLineEdit.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Your Locator"))
        self.label_11.setText(_translate("CassiopeiaConsoleWidget", "-n"))
        self.myNameLineEdit.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Your Name"))
        self.groupBox_3.setTitle(_translate("CassiopeiaConsoleWidget", "Event"))
        self.label_19.setText(_translate("CassiopeiaConsoleWidget", "$"))
        self.eventComboBox.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Event ID"))
        self.eventComboBox.setItemText(0, _translate("CassiopeiaConsoleWidget", "Event ID"))
        self.eventComboBox.setItemText(1, _translate("CassiopeiaConsoleWidget", "POTA"))
        self.eventComboBox.setItemText(2, _translate("CassiopeiaConsoleWidget", "SOTA"))
        self.label_21.setText(_translate("CassiopeiaConsoleWidget", "-N"))
        self.exchTXLineEdit.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Exchange"))
        self.label.setText(_translate("CassiopeiaConsoleWidget", "Tx"))
        self.label_20.setText(_translate("CassiopeiaConsoleWidget", "%"))
        self.exchRXLineEdit.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Exchange"))
        self.label_6.setText(_translate("CassiopeiaConsoleWidget", "Rx"))
        self.qsoDataGroupBox.setTitle(_translate("CassiopeiaConsoleWidget", "QSO Data"))
        self.dateEdit.setDisplayFormat(_translate("CassiopeiaConsoleWidget", "yyyy-MM-dd"))
        self.label_3.setText(_translate("CassiopeiaConsoleWidget", "d"))
        self.label_4.setText(_translate("CassiopeiaConsoleWidget", "t"))
        self.bandComboBox.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Band"))
        self.bandComboBox.setItemText(0, _translate("CassiopeiaConsoleWidget", "Band"))
        self.modeComboBox.setCurrentText(_translate("CassiopeiaConsoleWidget", "Mode"))
        self.modeComboBox.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Mode"))
        self.modeComboBox.setItemText(0, _translate("CassiopeiaConsoleWidget", "Mode"))
        self.callLineEdit.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Call"))
        self.label_9.setText(_translate("CassiopeiaConsoleWidget", "@"))
        self.locLineEdit.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Locator"))
        self.label_13.setText(_translate("CassiopeiaConsoleWidget", ","))
        self.rstTXLineEdit.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "RST"))
        self.label_7.setText(_translate("CassiopeiaConsoleWidget", "Tx"))
        self.label_12.setText(_translate("CassiopeiaConsoleWidget", "."))
        self.rstRXLineEdit.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "RST"))
        self.label_8.setText(_translate("CassiopeiaConsoleWidget", "Rx"))
        self.label_14.setText(_translate("CassiopeiaConsoleWidget", "\'"))
        self.nameLineEdit.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Name"))
        self.freqSpinBox.setSpecialValueText(_translate("CassiopeiaConsoleWidget", "n.a."))
        self.freqSpinBox.setSuffix(_translate("CassiopeiaConsoleWidget", " kHz"))
        self.label_16.setText(_translate("CassiopeiaConsoleWidget", "f"))
        self.powerSpinBox.setSpecialValueText(_translate("CassiopeiaConsoleWidget", "n.a."))
        self.powerSpinBox.setSuffix(_translate("CassiopeiaConsoleWidget", " W"))
        self.label_17.setText(_translate("CassiopeiaConsoleWidget", "p"))
        self.label_18.setText(_translate("CassiopeiaConsoleWidget", "*"))
        self.qslCheckBox.setText(_translate("CassiopeiaConsoleWidget", "QSL rcvd"))
        self.label_15.setText(_translate("CassiopeiaConsoleWidget", "#"))
        self.commentLineEdit.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Comment"))
        self.label_5.setText(_translate("CassiopeiaConsoleWidget", "QSO>"))
        self.inputLineEdit.setPlaceholderText(_translate("CassiopeiaConsoleWidget", "Input"))
        self.clearPushButton.setToolTip(_translate("CassiopeiaConsoleWidget", "Clear"))
        self.addQSOPushButton.setToolTip(_translate("CassiopeiaConsoleWidget", "Push to Log"))
        self.onlineCheckBox.setText(_translate("CassiopeiaConsoleWidget", "Online"))
