# Form implementation generated from reading ui file 'QSLQRReader.ui'
#
# Created by: PyQt6 UI code generator 6.9.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_QSLQRReaderDialog(object):
    def setupUi(self, QSLQRReaderDialog):
        QSLQRReaderDialog.setObjectName("QSLQRReaderDialog")
        QSLQRReaderDialog.resize(400, 330)
        self.verticalLayout = QtWidgets.QVBoxLayout(QSLQRReaderDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.frame = QtWidgets.QFrame(parent=QSLQRReaderDialog)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setFrameShape(QtWidgets.QFrame.Shape.StyledPanel)
        self.frame.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.frame.setObjectName("frame")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.frame)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.displayLabel = QtWidgets.QLabel(parent=self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.displayLabel.sizePolicy().hasHeightForWidth())
        self.displayLabel.setSizePolicy(sizePolicy)
        self.displayLabel.setText("")
        self.displayLabel.setObjectName("displayLabel")
        self.verticalLayout_2.addWidget(self.displayLabel)
        self.verticalLayout.addWidget(self.frame)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.srcLabel = QtWidgets.QLabel(parent=QSLQRReaderDialog)
        self.srcLabel.setObjectName("srcLabel")
        self.horizontalLayout_2.addWidget(self.srcLabel)
        self.videoSrcComboBox = QtWidgets.QComboBox(parent=QSLQRReaderDialog)
        self.videoSrcComboBox.setObjectName("videoSrcComboBox")
        self.horizontalLayout_2.addWidget(self.videoSrcComboBox)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.msgLabel = QtWidgets.QLabel(parent=QSLQRReaderDialog)
        self.msgLabel.setText("")
        self.msgLabel.setObjectName("msgLabel")
        self.verticalLayout.addWidget(self.msgLabel)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.okPushButton = QtWidgets.QPushButton(parent=QSLQRReaderDialog)
        self.okPushButton.setObjectName("okPushButton")
        self.horizontalLayout.addWidget(self.okPushButton)
        self.cancelPushButton = QtWidgets.QPushButton(parent=QSLQRReaderDialog)
        self.cancelPushButton.setObjectName("cancelPushButton")
        self.horizontalLayout.addWidget(self.cancelPushButton)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(QSLQRReaderDialog)
        self.okPushButton.clicked.connect(QSLQRReaderDialog.accept) # type: ignore
        self.cancelPushButton.clicked.connect(QSLQRReaderDialog.reject) # type: ignore
        self.videoSrcComboBox.currentTextChanged['QString'].connect(QSLQRReaderDialog.videoSrcChanged) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(QSLQRReaderDialog)

    def retranslateUi(self, QSLQRReaderDialog):
        _translate = QtCore.QCoreApplication.translate
        QSLQRReaderDialog.setWindowTitle(_translate("QSLQRReaderDialog", "Dialog"))
        self.srcLabel.setText(_translate("QSLQRReaderDialog", "Video source"))
        self.okPushButton.setText(_translate("QSLQRReaderDialog", "Ok"))
        self.cancelPushButton.setText(_translate("QSLQRReaderDialog", "Cancel"))
