# Form implementation generated from reading ui file 'DragonLog_QSOForm.ui'
#
# Created by: PyQt6 UI code generator 6.9.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_QSOForm(object):
    def setupUi(self, QSOForm):
        QSOForm.setObjectName("QSOForm")
        QSOForm.resize(450, 504)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(QSOForm.sizePolicy().hasHeightForWidth())
        QSOForm.setSizePolicy(sizePolicy)
        QSOForm.setMinimumSize(QtCore.QSize(450, 480))
        self.verticalLayout = QtWidgets.QVBoxLayout(QSOForm)
        self.verticalLayout.setObjectName("verticalLayout")
        self.toolBox = QtWidgets.QToolBox(parent=QSOForm)
        self.toolBox.setObjectName("toolBox")
        self.mainPage = QtWidgets.QWidget()
        self.mainPage.setGeometry(QtCore.QRect(0, 0, 432, 334))
        self.mainPage.setObjectName("mainPage")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.mainPage)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.nameLineEdit = QtWidgets.QLineEdit(parent=self.mainPage)
        self.nameLineEdit.setProperty("cssClass", "QSOFormInput")
        self.nameLineEdit.setObjectName("nameLineEdit")
        self.gridLayout_3.addWidget(self.nameLineEdit, 0, 1, 1, 1)
        self.locatorLineEdit = QtWidgets.QLineEdit(parent=self.mainPage)
        self.locatorLineEdit.setProperty("cssClass", "QSOFormInput")
        self.locatorLineEdit.setObjectName("locatorLineEdit")
        self.gridLayout_3.addWidget(self.locatorLineEdit, 1, 1, 1, 1)
        self.callSignLineEdit = QtWidgets.QLineEdit(parent=self.mainPage)
        self.callSignLineEdit.setProperty("cssClass", "QSOFormInput")
        self.callSignLineEdit.setObjectName("callSignLineEdit")
        self.gridLayout_3.addWidget(self.callSignLineEdit, 0, 0, 1, 1)
        self.QTHLineEdit = QtWidgets.QLineEdit(parent=self.mainPage)
        self.QTHLineEdit.setProperty("cssClass", "QSOFormInput")
        self.QTHLineEdit.setObjectName("QTHLineEdit")
        self.gridLayout_3.addWidget(self.QTHLineEdit, 1, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.gridLayout_3.addItem(spacerItem, 2, 0, 1, 1)
        self.verticalLayout_8.addLayout(self.gridLayout_3)
        self.horizontalLayout_11.addLayout(self.verticalLayout_8)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setSpacing(0)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.searchHamQTHPushButton = QtWidgets.QPushButton(parent=self.mainPage)
        self.searchHamQTHPushButton.setObjectName("searchHamQTHPushButton")
        self.verticalLayout_7.addWidget(self.searchHamQTHPushButton)
        self.searchQRZPushButton = QtWidgets.QPushButton(parent=self.mainPage)
        self.searchQRZPushButton.setObjectName("searchQRZPushButton")
        self.verticalLayout_7.addWidget(self.searchQRZPushButton)
        self.searchQRZCQPushButton = QtWidgets.QPushButton(parent=self.mainPage)
        self.searchQRZCQPushButton.setObjectName("searchQRZCQPushButton")
        self.verticalLayout_7.addWidget(self.searchQRZCQPushButton)
        self.horizontalLayout_11.addLayout(self.verticalLayout_7)
        self.verticalLayout_2.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.ctyCtyLabel = QtWidgets.QLabel(parent=self.mainPage)
        self.ctyCtyLabel.setText("")
        self.ctyCtyLabel.setObjectName("ctyCtyLabel")
        self.horizontalLayout_10.addWidget(self.ctyCtyLabel)
        self.line_4 = QtWidgets.QFrame(parent=self.mainPage)
        self.line_4.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_4.setObjectName("line_4")
        self.horizontalLayout_10.addWidget(self.line_4)
        self.ctyAreaLabel = QtWidgets.QLabel(parent=self.mainPage)
        self.ctyAreaLabel.setText("")
        self.ctyAreaLabel.setObjectName("ctyAreaLabel")
        self.horizontalLayout_10.addWidget(self.ctyAreaLabel)
        self.line_5 = QtWidgets.QFrame(parent=self.mainPage)
        self.line_5.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_5.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_5.setObjectName("line_5")
        self.horizontalLayout_10.addWidget(self.line_5)
        self.distLabel = QtWidgets.QLabel(parent=self.mainPage)
        self.distLabel.setText("")
        self.distLabel.setObjectName("distLabel")
        self.horizontalLayout_10.addWidget(self.distLabel)
        self.verticalLayout_2.addLayout(self.horizontalLayout_10)
        self.line = QtWidgets.QFrame(parent=self.mainPage)
        self.line.setFrameShape(QtWidgets.QFrame.Shape.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line.setObjectName("line")
        self.verticalLayout_2.addWidget(self.line)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label = QtWidgets.QLabel(parent=self.mainPage)
        self.label.setObjectName("label")
        self.horizontalLayout_9.addWidget(self.label)
        self.RSTSentLineEdit = QtWidgets.QLineEdit(parent=self.mainPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.RSTSentLineEdit.sizePolicy().hasHeightForWidth())
        self.RSTSentLineEdit.setSizePolicy(sizePolicy)
        self.RSTSentLineEdit.setMaximumSize(QtCore.QSize(100, 16777215))
        self.RSTSentLineEdit.setProperty("cssClass", "QSOFormInput")
        self.RSTSentLineEdit.setObjectName("RSTSentLineEdit")
        self.horizontalLayout_9.addWidget(self.RSTSentLineEdit)
        self.label_2 = QtWidgets.QLabel(parent=self.mainPage)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_9.addWidget(self.label_2)
        self.RSTRcvdLineEdit = QtWidgets.QLineEdit(parent=self.mainPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.RSTRcvdLineEdit.sizePolicy().hasHeightForWidth())
        self.RSTRcvdLineEdit.setSizePolicy(sizePolicy)
        self.RSTRcvdLineEdit.setMaximumSize(QtCore.QSize(100, 16777215))
        self.RSTRcvdLineEdit.setProperty("cssClass", "QSOFormInput")
        self.RSTRcvdLineEdit.setObjectName("RSTRcvdLineEdit")
        self.horizontalLayout_9.addWidget(self.RSTRcvdLineEdit)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem1)
        self.powerLabel = QtWidgets.QLabel(parent=self.mainPage)
        self.powerLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.powerLabel.setObjectName("powerLabel")
        self.horizontalLayout_9.addWidget(self.powerLabel)
        self.powerSpinBox = QtWidgets.QSpinBox(parent=self.mainPage)
        self.powerSpinBox.setEnabled(True)
        self.powerSpinBox.setMinimum(0)
        self.powerSpinBox.setMaximum(1000)
        self.powerSpinBox.setProperty("cssClass", "QSOFormInput")
        self.powerSpinBox.setObjectName("powerSpinBox")
        self.horizontalLayout_9.addWidget(self.powerSpinBox)
        self.verticalLayout_2.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.bandComboBox = QtWidgets.QComboBox(parent=self.mainPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bandComboBox.sizePolicy().hasHeightForWidth())
        self.bandComboBox.setSizePolicy(sizePolicy)
        self.bandComboBox.setMaximumSize(QtCore.QSize(100, 16777215))
        self.bandComboBox.setEditable(True)
        self.bandComboBox.setMinimumContentsLength(4)
        self.bandComboBox.setProperty("cssClass", "QSOFormInput")
        self.bandComboBox.setObjectName("bandComboBox")
        self.horizontalLayout_8.addWidget(self.bandComboBox)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem2)
        self.channelLabel = QtWidgets.QLabel(parent=self.mainPage)
        self.channelLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.channelLabel.setObjectName("channelLabel")
        self.horizontalLayout_8.addWidget(self.channelLabel)
        self.channelComboBox = QtWidgets.QComboBox(parent=self.mainPage)
        self.channelComboBox.setProperty("cssClass", "QSOFormInput")
        self.channelComboBox.setObjectName("channelComboBox")
        self.horizontalLayout_8.addWidget(self.channelComboBox)
        self.freqLabel = QtWidgets.QLabel(parent=self.mainPage)
        self.freqLabel.setAlignment(QtCore.Qt.AlignmentFlag.AlignRight|QtCore.Qt.AlignmentFlag.AlignTrailing|QtCore.Qt.AlignmentFlag.AlignVCenter)
        self.freqLabel.setObjectName("freqLabel")
        self.horizontalLayout_8.addWidget(self.freqLabel)
        self.freqDoubleSpinBox = QtWidgets.QDoubleSpinBox(parent=self.mainPage)
        self.freqDoubleSpinBox.setAccelerated(True)
        self.freqDoubleSpinBox.setDecimals(3)
        self.freqDoubleSpinBox.setMinimum(100.0)
        self.freqDoubleSpinBox.setMaximum(7500000000.0)
        self.freqDoubleSpinBox.setProperty("cssClass", "QSOFormInput")
        self.freqDoubleSpinBox.setObjectName("freqDoubleSpinBox")
        self.horizontalLayout_8.addWidget(self.freqDoubleSpinBox)
        self.verticalLayout_2.addLayout(self.horizontalLayout_8)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.modeComboBox = QtWidgets.QComboBox(parent=self.mainPage)
        self.modeComboBox.setEditable(True)
        self.modeComboBox.setMinimumContentsLength(2)
        self.modeComboBox.setProperty("cssClass", "QSOFormInput")
        self.modeComboBox.setObjectName("modeComboBox")
        self.horizontalLayout_14.addWidget(self.modeComboBox)
        self.submodeComboBox = QtWidgets.QComboBox(parent=self.mainPage)
        self.submodeComboBox.setProperty("cssClass", "QSOFormInput")
        self.submodeComboBox.setObjectName("submodeComboBox")
        self.horizontalLayout_14.addWidget(self.submodeComboBox)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem3)
        self.propComboBox = QtWidgets.QComboBox(parent=self.mainPage)
        self.propComboBox.setProperty("cssClass", "QSOFormInput")
        self.propComboBox.setObjectName("propComboBox")
        self.horizontalLayout_14.addWidget(self.propComboBox)
        self.verticalLayout_2.addLayout(self.horizontalLayout_14)
        self.line_2 = QtWidgets.QFrame(parent=self.mainPage)
        self.line_2.setFrameShape(QtWidgets.QFrame.Shape.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_2.setObjectName("line_2")
        self.verticalLayout_2.addWidget(self.line_2)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.timeNowPushButton = QtWidgets.QPushButton(parent=self.mainPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Maximum, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.timeNowPushButton.sizePolicy().hasHeightForWidth())
        self.timeNowPushButton.setSizePolicy(sizePolicy)
        self.timeNowPushButton.setObjectName("timeNowPushButton")
        self.gridLayout.addWidget(self.timeNowPushButton, 0, 3, 1, 1)
        spacerItem4 = QtWidgets.QSpacerItem(100, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem4, 0, 4, 1, 1)
        self.label_3 = QtWidgets.QLabel(parent=self.mainPage)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 0, 0, 1, 1)
        self.timeOffEdit = QtWidgets.QLineEdit(parent=self.mainPage)
        self.timeOffEdit.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.timeOffEdit.sizePolicy().hasHeightForWidth())
        self.timeOffEdit.setSizePolicy(sizePolicy)
        self.timeOffEdit.setProperty("cssClass", "QSOFormInput")
        self.timeOffEdit.setObjectName("timeOffEdit")
        self.gridLayout.addWidget(self.timeOffEdit, 1, 2, 1, 1)
        self.dateOnEdit = QtWidgets.QDateEdit(parent=self.mainPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dateOnEdit.sizePolicy().hasHeightForWidth())
        self.dateOnEdit.setSizePolicy(sizePolicy)
        self.dateOnEdit.setMinimumSize(QtCore.QSize(100, 0))
        self.dateOnEdit.setCalendarPopup(True)
        self.dateOnEdit.setProperty("cssClass", "QSOFormInput")
        self.dateOnEdit.setObjectName("dateOnEdit")
        self.gridLayout.addWidget(self.dateOnEdit, 0, 1, 1, 1)
        self.label_4 = QtWidgets.QLabel(parent=self.mainPage)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 1, 0, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(100, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout.addItem(spacerItem5, 1, 4, 1, 1)
        self.dateOffEdit = QtWidgets.QDateEdit(parent=self.mainPage)
        self.dateOffEdit.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dateOffEdit.sizePolicy().hasHeightForWidth())
        self.dateOffEdit.setSizePolicy(sizePolicy)
        self.dateOffEdit.setMinimumSize(QtCore.QSize(100, 0))
        self.dateOffEdit.setCalendarPopup(True)
        self.dateOffEdit.setTimeSpec(QtCore.Qt.TimeSpec.UTC)
        self.dateOffEdit.setProperty("cssClass", "QSOFormInput")
        self.dateOffEdit.setObjectName("dateOffEdit")
        self.gridLayout.addWidget(self.dateOffEdit, 1, 1, 1, 1)
        self.autoDateCheckBox = QtWidgets.QCheckBox(parent=self.mainPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.autoDateCheckBox.sizePolicy().hasHeightForWidth())
        self.autoDateCheckBox.setSizePolicy(sizePolicy)
        self.autoDateCheckBox.setChecked(True)
        self.autoDateCheckBox.setObjectName("autoDateCheckBox")
        self.gridLayout.addWidget(self.autoDateCheckBox, 1, 3, 1, 1)
        self.timeOnEdit = QtWidgets.QLineEdit(parent=self.mainPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Preferred, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.timeOnEdit.sizePolicy().hasHeightForWidth())
        self.timeOnEdit.setSizePolicy(sizePolicy)
        self.timeOnEdit.setProperty("cssClass", "QSOFormInput")
        self.timeOnEdit.setObjectName("timeOnEdit")
        self.gridLayout.addWidget(self.timeOnEdit, 0, 2, 1, 1)
        self.verticalLayout_2.addLayout(self.gridLayout)
        self.line_3 = QtWidgets.QFrame(parent=self.mainPage)
        self.line_3.setFrameShape(QtWidgets.QFrame.Shape.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_3.setObjectName("line_3")
        self.verticalLayout_2.addWidget(self.line_3)
        self.commentLineEdit = QtWidgets.QLineEdit(parent=self.mainPage)
        self.commentLineEdit.setProperty("cssClass", "QSOFormInput")
        self.commentLineEdit.setObjectName("commentLineEdit")
        self.verticalLayout_2.addWidget(self.commentLineEdit)
        self.verticalLayout_5.addLayout(self.verticalLayout_2)
        spacerItem6 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        self.verticalLayout_5.addItem(spacerItem6)
        self.toolBox.addItem(self.mainPage, "")
        self.stationPage = QtWidgets.QWidget()
        self.stationPage.setGeometry(QtCore.QRect(0, 0, 432, 334))
        self.stationPage.setObjectName("stationPage")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.stationPage)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.identityGroupBox = QtWidgets.QGroupBox(parent=self.stationPage)
        self.identityGroupBox.setCheckable(True)
        self.identityGroupBox.setObjectName("identityGroupBox")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.identityGroupBox)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.ownCallSignLineEdit = QtWidgets.QLineEdit(parent=self.identityGroupBox)
        self.ownCallSignLineEdit.setEnabled(False)
        self.ownCallSignLineEdit.setProperty("cssClass", "QSOFormInput")
        self.ownCallSignLineEdit.setObjectName("ownCallSignLineEdit")
        self.horizontalLayout_5.addWidget(self.ownCallSignLineEdit)
        self.ownNameLineEdit = QtWidgets.QLineEdit(parent=self.identityGroupBox)
        self.ownNameLineEdit.setEnabled(False)
        self.ownNameLineEdit.setProperty("cssClass", "QSOFormInput")
        self.ownNameLineEdit.setObjectName("ownNameLineEdit")
        self.horizontalLayout_5.addWidget(self.ownNameLineEdit)
        self.verticalLayout_3.addLayout(self.horizontalLayout_5)
        self.verticalLayout_10.addWidget(self.identityGroupBox)
        self.stationGroupBox = QtWidgets.QGroupBox(parent=self.stationPage)
        self.stationGroupBox.setCheckable(True)
        self.stationGroupBox.setObjectName("stationGroupBox")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.stationGroupBox)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.ownQTHComboBox = QtWidgets.QComboBox(parent=self.stationGroupBox)
        self.ownQTHComboBox.setEnabled(False)
        self.ownQTHComboBox.setAutoFillBackground(True)
        self.ownQTHComboBox.setEditable(True)
        self.ownQTHComboBox.setProperty("cssClass", "QSOFormInput")
        self.ownQTHComboBox.setObjectName("ownQTHComboBox")
        self.horizontalLayout_7.addWidget(self.ownQTHComboBox)
        self.verticalLayout_4.addLayout(self.horizontalLayout_7)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.radioComboBox = QtWidgets.QComboBox(parent=self.stationGroupBox)
        self.radioComboBox.setEnabled(False)
        self.radioComboBox.setEditable(True)
        self.radioComboBox.setProperty("cssClass", "QSOFormInput")
        self.radioComboBox.setObjectName("radioComboBox")
        self.horizontalLayout_6.addWidget(self.radioComboBox)
        self.antennaComboBox = QtWidgets.QComboBox(parent=self.stationGroupBox)
        self.antennaComboBox.setEnabled(False)
        self.antennaComboBox.setEditable(True)
        self.antennaComboBox.setProperty("cssClass", "QSOFormInput")
        self.antennaComboBox.setObjectName("antennaComboBox")
        self.horizontalLayout_6.addWidget(self.antennaComboBox)
        self.verticalLayout_4.addLayout(self.horizontalLayout_6)
        self.verticalLayout_10.addWidget(self.stationGroupBox)
        self.remarksTextEdit = QtWidgets.QTextEdit(parent=self.stationPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.remarksTextEdit.sizePolicy().hasHeightForWidth())
        self.remarksTextEdit.setSizePolicy(sizePolicy)
        self.remarksTextEdit.setMinimumSize(QtCore.QSize(0, 50))
        self.remarksTextEdit.setMaximumSize(QtCore.QSize(16777215, 100))
        self.remarksTextEdit.setAcceptRichText(False)
        self.remarksTextEdit.setTextInteractionFlags(QtCore.Qt.TextInteractionFlag.LinksAccessibleByKeyboard|QtCore.Qt.TextInteractionFlag.LinksAccessibleByMouse|QtCore.Qt.TextInteractionFlag.TextBrowserInteraction|QtCore.Qt.TextInteractionFlag.TextEditable|QtCore.Qt.TextInteractionFlag.TextEditorInteraction|QtCore.Qt.TextInteractionFlag.TextSelectableByKeyboard|QtCore.Qt.TextInteractionFlag.TextSelectableByMouse)
        self.remarksTextEdit.setProperty("cssClass", "QSOFormInput")
        self.remarksTextEdit.setObjectName("remarksTextEdit")
        self.verticalLayout_10.addWidget(self.remarksTextEdit)
        spacerItem7 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        self.verticalLayout_10.addItem(spacerItem7)
        self.toolBox.addItem(self.stationPage, "")
        self.qslPage = QtWidgets.QWidget()
        self.qslPage.setGeometry(QtCore.QRect(0, 0, 432, 334))
        self.qslPage.setObjectName("qslPage")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.qslPage)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.qslViaLineEdit = QtWidgets.QLineEdit(parent=self.qslPage)
        self.qslViaLineEdit.setProperty("cssClass", "QSOFormInput")
        self.qslViaLineEdit.setObjectName("qslViaLineEdit")
        self.verticalLayout_6.addWidget(self.qslViaLineEdit)
        self.qslMessageTextEdit = QtWidgets.QTextEdit(parent=self.qslPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.qslMessageTextEdit.sizePolicy().hasHeightForWidth())
        self.qslMessageTextEdit.setSizePolicy(sizePolicy)
        self.qslMessageTextEdit.setMinimumSize(QtCore.QSize(0, 50))
        self.qslMessageTextEdit.setMaximumSize(QtCore.QSize(16777215, 50))
        self.qslMessageTextEdit.setTextInteractionFlags(QtCore.Qt.TextInteractionFlag.LinksAccessibleByKeyboard|QtCore.Qt.TextInteractionFlag.LinksAccessibleByMouse|QtCore.Qt.TextInteractionFlag.TextBrowserInteraction|QtCore.Qt.TextInteractionFlag.TextEditable|QtCore.Qt.TextInteractionFlag.TextEditorInteraction|QtCore.Qt.TextInteractionFlag.TextSelectableByKeyboard|QtCore.Qt.TextInteractionFlag.TextSelectableByMouse)
        self.qslMessageTextEdit.setProperty("cssClass", "QSOFormInput")
        self.qslMessageTextEdit.setObjectName("qslMessageTextEdit")
        self.verticalLayout_6.addWidget(self.qslMessageTextEdit)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.label_5 = QtWidgets.QLabel(parent=self.qslPage)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_12.addWidget(self.label_5)
        self.qslAccBureauCheckBox = QtWidgets.QCheckBox(parent=self.qslPage)
        self.qslAccBureauCheckBox.setObjectName("qslAccBureauCheckBox")
        self.horizontalLayout_12.addWidget(self.qslAccBureauCheckBox)
        self.qslAccDirectCheckBox = QtWidgets.QCheckBox(parent=self.qslPage)
        self.qslAccDirectCheckBox.setObjectName("qslAccDirectCheckBox")
        self.horizontalLayout_12.addWidget(self.qslAccDirectCheckBox)
        self.qslAcceQSLCheckBox = QtWidgets.QCheckBox(parent=self.qslPage)
        self.qslAcceQSLCheckBox.setObjectName("qslAcceQSLCheckBox")
        self.horizontalLayout_12.addWidget(self.qslAcceQSLCheckBox)
        self.qslAccLoTWCheckBox = QtWidgets.QCheckBox(parent=self.qslPage)
        self.qslAccLoTWCheckBox.setObjectName("qslAccLoTWCheckBox")
        self.horizontalLayout_12.addWidget(self.qslAccLoTWCheckBox)
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_12.addItem(spacerItem8)
        self.verticalLayout_6.addLayout(self.horizontalLayout_12)
        self.qslBurDirGroupBox = QtWidgets.QGroupBox(parent=self.qslPage)
        self.qslBurDirGroupBox.setCheckable(True)
        self.qslBurDirGroupBox.setChecked(False)
        self.qslBurDirGroupBox.setObjectName("qslBurDirGroupBox")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.qslBurDirGroupBox)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.gridLayout_4 = QtWidgets.QGridLayout()
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.qslBureauRadioButton = QtWidgets.QRadioButton(parent=self.qslBurDirGroupBox)
        self.qslBureauRadioButton.setChecked(True)
        self.qslBureauRadioButton.setObjectName("qslBureauRadioButton")
        self.gridLayout_4.addWidget(self.qslBureauRadioButton, 0, 0, 1, 1)
        self.qslDirectRadioButton = QtWidgets.QRadioButton(parent=self.qslBurDirGroupBox)
        self.qslDirectRadioButton.setObjectName("qslDirectRadioButton")
        self.gridLayout_4.addWidget(self.qslDirectRadioButton, 0, 1, 1, 1)
        self.qslSentCheckBox = QtWidgets.QCheckBox(parent=self.qslBurDirGroupBox)
        self.qslSentCheckBox.setObjectName("qslSentCheckBox")
        self.gridLayout_4.addWidget(self.qslSentCheckBox, 1, 0, 1, 1)
        self.qslRcvdCheckBox = QtWidgets.QCheckBox(parent=self.qslBurDirGroupBox)
        self.qslRcvdCheckBox.setObjectName("qslRcvdCheckBox")
        self.gridLayout_4.addWidget(self.qslRcvdCheckBox, 1, 1, 1, 1)
        self.gridLayout_2.addLayout(self.gridLayout_4, 1, 0, 1, 1)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.gridLayout_2.addItem(spacerItem9, 1, 1, 1, 1)
        self.verticalLayout_6.addWidget(self.qslBurDirGroupBox)
        spacerItem10 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        self.verticalLayout_6.addItem(spacerItem10)
        self.toolBox.addItem(self.qslPage, "")
        self.contestPage = QtWidgets.QWidget()
        self.contestPage.setGeometry(QtCore.QRect(0, 0, 432, 334))
        self.contestPage.setObjectName("contestPage")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.contestPage)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.contestGroupBox = QtWidgets.QGroupBox(parent=self.contestPage)
        self.contestGroupBox.setObjectName("contestGroupBox")
        self.formLayout_2 = QtWidgets.QFormLayout(self.contestGroupBox)
        self.formLayout_2.setObjectName("formLayout_2")
        self.label_10 = QtWidgets.QLabel(parent=self.contestGroupBox)
        self.label_10.setObjectName("label_10")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_10)
        self.contestComboBox = QtWidgets.QComboBox(parent=self.contestGroupBox)
        self.contestComboBox.setEditable(True)
        self.contestComboBox.setProperty("cssClass", "QSOFormInput")
        self.contestComboBox.setObjectName("contestComboBox")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.contestComboBox)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.sentQSOSpinBox = QtWidgets.QSpinBox(parent=self.contestGroupBox)
        self.sentQSOSpinBox.setMinimum(0)
        self.sentQSOSpinBox.setMaximum(999)
        self.sentQSOSpinBox.setProperty("value", 0)
        self.sentQSOSpinBox.setProperty("cssClass", "QSOFormInput")
        self.sentQSOSpinBox.setObjectName("sentQSOSpinBox")
        self.horizontalLayout.addWidget(self.sentQSOSpinBox)
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem11)
        self.formLayout_2.setLayout(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.horizontalLayout)
        self.label_6 = QtWidgets.QLabel(parent=self.contestGroupBox)
        self.label_6.setObjectName("label_6")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_6)
        self.label_9 = QtWidgets.QLabel(parent=self.contestGroupBox)
        self.label_9.setObjectName("label_9")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_9)
        self.rcvdDataLineEdit = QtWidgets.QLineEdit(parent=self.contestGroupBox)
        self.rcvdDataLineEdit.setProperty("cssClass", "QSOFormInput")
        self.rcvdDataLineEdit.setObjectName("rcvdDataLineEdit")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.rcvdDataLineEdit)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.rcvdQSOSpinBox = QtWidgets.QSpinBox(parent=self.contestGroupBox)
        self.rcvdQSOSpinBox.setMinimum(0)
        self.rcvdQSOSpinBox.setMaximum(999)
        self.rcvdQSOSpinBox.setProperty("value", 0)
        self.rcvdQSOSpinBox.setProperty("cssClass", "QSOFormInput")
        self.rcvdQSOSpinBox.setObjectName("rcvdQSOSpinBox")
        self.horizontalLayout_4.addWidget(self.rcvdQSOSpinBox)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem12)
        self.formLayout_2.setLayout(3, QtWidgets.QFormLayout.ItemRole.FieldRole, self.horizontalLayout_4)
        self.label_8 = QtWidgets.QLabel(parent=self.contestGroupBox)
        self.label_8.setObjectName("label_8")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_8)
        self.verticalLayout_9.addWidget(self.contestGroupBox)
        self.xotaGroupBox = QtWidgets.QGroupBox(parent=self.contestPage)
        self.xotaGroupBox.setObjectName("xotaGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.xotaGroupBox)
        self.formLayout.setObjectName("formLayout")
        self.eventComboBox = QtWidgets.QComboBox(parent=self.xotaGroupBox)
        self.eventComboBox.setProperty("cssClass", "QSOFormInput")
        self.eventComboBox.setObjectName("eventComboBox")
        self.eventComboBox.addItem("")
        self.eventComboBox.setItemText(0, "")
        self.eventComboBox.addItem("")
        self.eventComboBox.addItem("")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.eventComboBox)
        self.label_7 = QtWidgets.QLabel(parent=self.xotaGroupBox)
        self.label_7.setObjectName("label_7")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_7)
        self.label_11 = QtWidgets.QLabel(parent=self.xotaGroupBox)
        self.label_11.setObjectName("label_11")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_11)
        self.txExchLineEdit = QtWidgets.QLineEdit(parent=self.xotaGroupBox)
        self.txExchLineEdit.setProperty("cssClass", "QSOFormInput")
        self.txExchLineEdit.setObjectName("txExchLineEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.txExchLineEdit)
        self.label_12 = QtWidgets.QLabel(parent=self.xotaGroupBox)
        self.label_12.setObjectName("label_12")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_12)
        self.rxExchLineEdit = QtWidgets.QLineEdit(parent=self.xotaGroupBox)
        self.rxExchLineEdit.setProperty("cssClass", "QSOFormInput")
        self.rxExchLineEdit.setObjectName("rxExchLineEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.rxExchLineEdit)
        self.verticalLayout_9.addWidget(self.xotaGroupBox)
        spacerItem13 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        self.verticalLayout_9.addItem(spacerItem13)
        self.toolBox.addItem(self.contestPage, "")
        self.verticalLayout.addWidget(self.toolBox)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem14 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem14)
        self.savePushButton = QtWidgets.QPushButton(parent=QSOForm)
        self.savePushButton.setObjectName("savePushButton")
        self.horizontalLayout_2.addWidget(self.savePushButton)
        self.cancelPushButton = QtWidgets.QPushButton(parent=QSOForm)
        self.cancelPushButton.setObjectName("cancelPushButton")
        self.horizontalLayout_2.addWidget(self.cancelPushButton)
        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.retranslateUi(QSOForm)
        self.toolBox.setCurrentIndex(0)
        self.savePushButton.clicked.connect(QSOForm.saveLog) # type: ignore
        self.autoDateCheckBox.toggled['bool'].connect(self.dateOffEdit.setDisabled) # type: ignore
        self.bandComboBox.currentTextChanged['QString'].connect(QSOForm.bandChanged) # type: ignore
        self.stationGroupBox.toggled['bool'].connect(QSOForm.stationChanged) # type: ignore
        self.identityGroupBox.toggled['bool'].connect(QSOForm.identityChanged) # type: ignore
        self.identityGroupBox.toggled['bool'].connect(self.ownCallSignLineEdit.setDisabled) # type: ignore
        self.identityGroupBox.toggled['bool'].connect(self.ownNameLineEdit.setDisabled) # type: ignore
        self.channelComboBox.currentTextChanged['QString'].connect(QSOForm.channelChanged) # type: ignore
        self.RSTRcvdLineEdit.textEdited['QString'].connect(QSOForm.rstRcvdChanged) # type: ignore
        self.RSTSentLineEdit.textEdited['QString'].connect(QSOForm.rstSentChanged) # type: ignore
        self.locatorLineEdit.textEdited['QString'].connect(QSOForm.locatorChanged) # type: ignore
        self.callSignLineEdit.textEdited['QString'].connect(QSOForm.callSignChanged) # type: ignore
        self.ownCallSignLineEdit.textEdited['QString'].connect(QSOForm.ownCallSignChanged) # type: ignore
        self.callSignLineEdit.editingFinished.connect(QSOForm.callEditingFinished) # type: ignore
        self.timeNowPushButton.clicked.connect(QSOForm.setStartTimeNow) # type: ignore
        self.searchHamQTHPushButton.clicked.connect(QSOForm.searchHamQTH) # type: ignore
        self.cancelPushButton.clicked.connect(QSOForm.clear) # type: ignore
        self.modeComboBox.currentTextChanged['QString'].connect(QSOForm.modeChanged) # type: ignore
        self.autoDateCheckBox.toggled['bool'].connect(self.timeOffEdit.setDisabled) # type: ignore
        self.timeOnEdit.textEdited['QString'].connect(QSOForm.timeOnChanged) # type: ignore
        self.timeOffEdit.textEdited['QString'].connect(QSOForm.timeOffChanged) # type: ignore
        self.autoDateCheckBox.toggled['bool'].connect(QSOForm.autoDateCBChanged) # type: ignore
        self.searchQRZCQPushButton.clicked.connect(QSOForm.searchQRZCQ) # type: ignore
        self.stationGroupBox.toggled['bool'].connect(self.antennaComboBox.setDisabled) # type: ignore
        self.stationGroupBox.toggled['bool'].connect(self.radioComboBox.setDisabled) # type: ignore
        self.stationGroupBox.toggled['bool'].connect(self.ownQTHComboBox.setDisabled) # type: ignore
        self.ownQTHComboBox.editTextChanged['QString'].connect(QSOForm.ownQTHChanged) # type: ignore
        self.contestComboBox.currentTextChanged['QString'].connect(QSOForm.contestChanged) # type: ignore
        self.eventComboBox.currentTextChanged['QString'].connect(QSOForm.eventChanged) # type: ignore
        self.searchQRZPushButton.clicked.connect(QSOForm.searchQRZ) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(QSOForm)
        QSOForm.setTabOrder(self.callSignLineEdit, self.nameLineEdit)
        QSOForm.setTabOrder(self.nameLineEdit, self.QTHLineEdit)
        QSOForm.setTabOrder(self.QTHLineEdit, self.locatorLineEdit)
        QSOForm.setTabOrder(self.locatorLineEdit, self.RSTSentLineEdit)
        QSOForm.setTabOrder(self.RSTSentLineEdit, self.RSTRcvdLineEdit)
        QSOForm.setTabOrder(self.RSTRcvdLineEdit, self.powerSpinBox)
        QSOForm.setTabOrder(self.powerSpinBox, self.bandComboBox)
        QSOForm.setTabOrder(self.bandComboBox, self.channelComboBox)
        QSOForm.setTabOrder(self.channelComboBox, self.freqDoubleSpinBox)
        QSOForm.setTabOrder(self.freqDoubleSpinBox, self.modeComboBox)
        QSOForm.setTabOrder(self.modeComboBox, self.submodeComboBox)
        QSOForm.setTabOrder(self.submodeComboBox, self.propComboBox)
        QSOForm.setTabOrder(self.propComboBox, self.dateOnEdit)
        QSOForm.setTabOrder(self.dateOnEdit, self.timeOnEdit)
        QSOForm.setTabOrder(self.timeOnEdit, self.timeNowPushButton)
        QSOForm.setTabOrder(self.timeNowPushButton, self.dateOffEdit)
        QSOForm.setTabOrder(self.dateOffEdit, self.timeOffEdit)
        QSOForm.setTabOrder(self.timeOffEdit, self.autoDateCheckBox)
        QSOForm.setTabOrder(self.autoDateCheckBox, self.commentLineEdit)
        QSOForm.setTabOrder(self.commentLineEdit, self.savePushButton)
        QSOForm.setTabOrder(self.savePushButton, self.cancelPushButton)
        QSOForm.setTabOrder(self.cancelPushButton, self.identityGroupBox)
        QSOForm.setTabOrder(self.identityGroupBox, self.ownCallSignLineEdit)
        QSOForm.setTabOrder(self.ownCallSignLineEdit, self.ownNameLineEdit)
        QSOForm.setTabOrder(self.ownNameLineEdit, self.stationGroupBox)
        QSOForm.setTabOrder(self.stationGroupBox, self.ownQTHComboBox)
        QSOForm.setTabOrder(self.ownQTHComboBox, self.radioComboBox)
        QSOForm.setTabOrder(self.radioComboBox, self.antennaComboBox)
        QSOForm.setTabOrder(self.antennaComboBox, self.remarksTextEdit)
        QSOForm.setTabOrder(self.remarksTextEdit, self.qslViaLineEdit)
        QSOForm.setTabOrder(self.qslViaLineEdit, self.qslMessageTextEdit)
        QSOForm.setTabOrder(self.qslMessageTextEdit, self.qslAccBureauCheckBox)
        QSOForm.setTabOrder(self.qslAccBureauCheckBox, self.qslAccDirectCheckBox)
        QSOForm.setTabOrder(self.qslAccDirectCheckBox, self.qslAcceQSLCheckBox)
        QSOForm.setTabOrder(self.qslAcceQSLCheckBox, self.qslAccLoTWCheckBox)
        QSOForm.setTabOrder(self.qslAccLoTWCheckBox, self.qslBurDirGroupBox)
        QSOForm.setTabOrder(self.qslBurDirGroupBox, self.qslBureauRadioButton)
        QSOForm.setTabOrder(self.qslBureauRadioButton, self.qslDirectRadioButton)
        QSOForm.setTabOrder(self.qslDirectRadioButton, self.qslSentCheckBox)
        QSOForm.setTabOrder(self.qslSentCheckBox, self.qslRcvdCheckBox)
        QSOForm.setTabOrder(self.qslRcvdCheckBox, self.contestComboBox)
        QSOForm.setTabOrder(self.contestComboBox, self.sentQSOSpinBox)
        QSOForm.setTabOrder(self.sentQSOSpinBox, self.rcvdDataLineEdit)
        QSOForm.setTabOrder(self.rcvdDataLineEdit, self.rcvdQSOSpinBox)
        QSOForm.setTabOrder(self.rcvdQSOSpinBox, self.eventComboBox)
        QSOForm.setTabOrder(self.eventComboBox, self.txExchLineEdit)
        QSOForm.setTabOrder(self.txExchLineEdit, self.rxExchLineEdit)

    def retranslateUi(self, QSOForm):
        _translate = QtCore.QCoreApplication.translate
        QSOForm.setWindowTitle(_translate("QSOForm", "QSO Form"))
        self.nameLineEdit.setPlaceholderText(_translate("QSOForm", "Name"))
        self.locatorLineEdit.setPlaceholderText(_translate("QSOForm", "Locator"))
        self.callSignLineEdit.setPlaceholderText(_translate("QSOForm", "Call sign"))
        self.QTHLineEdit.setPlaceholderText(_translate("QSOForm", "QTH"))
        self.searchHamQTHPushButton.setToolTip(_translate("QSOForm", "Lookup at HamQTH.com (Ctrl+Alt+H)"))
        self.searchHamQTHPushButton.setText(_translate("QSOForm", "HamQTH"))
        self.searchHamQTHPushButton.setShortcut(_translate("QSOForm", "Ctrl+Alt+H"))
        self.searchQRZPushButton.setToolTip(_translate("QSOForm", "Lookup at QRZ.com (Ctrl+Shift+Q)"))
        self.searchQRZPushButton.setText(_translate("QSOForm", "QRZ"))
        self.searchQRZPushButton.setShortcut(_translate("QSOForm", "Ctrl+Shift+Q"))
        self.searchQRZCQPushButton.setToolTip(_translate("QSOForm", "Lookup at QRZCQ.com (Ctrl+Alt+Z)"))
        self.searchQRZCQPushButton.setText(_translate("QSOForm", "QRZCQ"))
        self.searchQRZCQPushButton.setShortcut(_translate("QSOForm", "Ctrl+Alt+Z"))
        self.label.setText(_translate("QSOForm", "RST Tx"))
        self.RSTSentLineEdit.setText(_translate("QSOForm", "59"))
        self.RSTSentLineEdit.setPlaceholderText(_translate("QSOForm", "RST sent"))
        self.label_2.setText(_translate("QSOForm", "RST Rx"))
        self.RSTRcvdLineEdit.setText(_translate("QSOForm", "59"))
        self.RSTRcvdLineEdit.setPlaceholderText(_translate("QSOForm", "RST received"))
        self.powerLabel.setText(_translate("QSOForm", "Power"))
        self.powerSpinBox.setSpecialValueText(_translate("QSOForm", "n.a."))
        self.powerSpinBox.setSuffix(_translate("QSOForm", " W"))
        self.bandComboBox.setPlaceholderText(_translate("QSOForm", "Band"))
        self.channelLabel.setText(_translate("QSOForm", "Channel"))
        self.freqLabel.setText(_translate("QSOForm", "Frequency"))
        self.freqDoubleSpinBox.setSpecialValueText(_translate("QSOForm", "n.a."))
        self.freqDoubleSpinBox.setSuffix(_translate("QSOForm", " kHz"))
        self.modeComboBox.setPlaceholderText(_translate("QSOForm", "Mode"))
        self.submodeComboBox.setPlaceholderText(_translate("QSOForm", "Submode"))
        self.propComboBox.setPlaceholderText(_translate("QSOForm", "Propagation"))
        self.timeNowPushButton.setText(_translate("QSOForm", "Now"))
        self.timeNowPushButton.setShortcut(_translate("QSOForm", "Ctrl+Alt+N"))
        self.label_3.setText(_translate("QSOForm", "Start"))
        self.timeOffEdit.setPlaceholderText(_translate("QSOForm", "Time end"))
        self.dateOnEdit.setDisplayFormat(_translate("QSOForm", "yyyy-MM-dd"))
        self.label_4.setText(_translate("QSOForm", "End"))
        self.dateOffEdit.setDisplayFormat(_translate("QSOForm", "yyyy-MM-dd"))
        self.autoDateCheckBox.setText(_translate("QSOForm", "Automatically"))
        self.timeOnEdit.setPlaceholderText(_translate("QSOForm", "Time start"))
        self.commentLineEdit.setPlaceholderText(_translate("QSOForm", "QSO comment"))
        self.toolBox.setItemText(self.toolBox.indexOf(self.mainPage), _translate("QSOForm", "Main data"))
        self.identityGroupBox.setTitle(_translate("QSOForm", "Configured identity"))
        self.ownCallSignLineEdit.setPlaceholderText(_translate("QSOForm", "Own call sign"))
        self.ownNameLineEdit.setPlaceholderText(_translate("QSOForm", "Own name"))
        self.stationGroupBox.setTitle(_translate("QSOForm", "Configured station"))
        self.remarksTextEdit.setPlaceholderText(_translate("QSOForm", "Own notes"))
        self.toolBox.setItemText(self.toolBox.indexOf(self.stationPage), _translate("QSOForm", "Own data"))
        self.qslViaLineEdit.setToolTip(_translate("QSOForm", "The contacted station QSL route.\n"
"This is not the QSL manager/bureau address."))
        self.qslViaLineEdit.setPlaceholderText(_translate("QSOForm", "QSL via"))
        self.qslMessageTextEdit.setPlaceholderText(_translate("QSOForm", "QSL card message"))
        self.label_5.setText(_translate("QSOForm", "Accepts:"))
        self.qslAccBureauCheckBox.setText(_translate("QSOForm", "Bureau"))
        self.qslAccDirectCheckBox.setText(_translate("QSOForm", "Direct"))
        self.qslAcceQSLCheckBox.setText(_translate("QSOForm", "eQSL"))
        self.qslAccLoTWCheckBox.setText(_translate("QSOForm", "LoTW"))
        self.qslBurDirGroupBox.setTitle(_translate("QSOForm", "Bureau/Direct"))
        self.qslBureauRadioButton.setText(_translate("QSOForm", "Bureau"))
        self.qslDirectRadioButton.setText(_translate("QSOForm", "Direct"))
        self.qslSentCheckBox.setText(_translate("QSOForm", "QSL sent"))
        self.qslRcvdCheckBox.setText(_translate("QSOForm", "QSL received"))
        self.toolBox.setItemText(self.toolBox.indexOf(self.qslPage), _translate("QSOForm", "QSL"))
        self.contestGroupBox.setTitle(_translate("QSOForm", "Contest"))
        self.label_10.setText(_translate("QSOForm", "Contest ID"))
        self.contestComboBox.setPlaceholderText(_translate("QSOForm", "Contest ID"))
        self.sentQSOSpinBox.setSpecialValueText(_translate("QSOForm", "n.a."))
        self.label_6.setText(_translate("QSOForm", "Sent QSO ID"))
        self.label_9.setText(_translate("QSOForm", "Rx Exchange"))
        self.rcvdDataLineEdit.setPlaceholderText(_translate("QSOForm", "Rx Exchange"))
        self.rcvdQSOSpinBox.setSpecialValueText(_translate("QSOForm", "n.a."))
        self.label_8.setText(_translate("QSOForm", "Rcvd QSO ID"))
        self.xotaGroupBox.setTitle(_translate("QSOForm", "xOTA"))
        self.eventComboBox.setItemText(1, _translate("QSOForm", "POTA"))
        self.eventComboBox.setItemText(2, _translate("QSOForm", "SOTA"))
        self.label_7.setText(_translate("QSOForm", "Event"))
        self.label_11.setText(_translate("QSOForm", "Tx Exchange"))
        self.txExchLineEdit.setPlaceholderText(_translate("QSOForm", "Tx Exchange"))
        self.label_12.setText(_translate("QSOForm", "Rx Exchange"))
        self.rxExchLineEdit.setPlaceholderText(_translate("QSOForm", "Rx Exchange"))
        self.toolBox.setItemText(self.toolBox.indexOf(self.contestPage), _translate("QSOForm", "Contest && xOTA"))
        self.savePushButton.setText(_translate("QSOForm", "Save"))
        self.savePushButton.setShortcut(_translate("QSOForm", "Ctrl+S"))
        self.cancelPushButton.setText(_translate("QSOForm", "Clear"))
