# DragonLog © 2023-2024 by Andreas Schawo is licensed under CC BY-SA 4.0.
# To view a copy of this license, visit http://creativecommons.org/licenses/by-sa/4.0/

from . import DragonLog

DragonLog.main()
