# Form implementation generated from reading ui file 'DragonLog_AppSelect.ui'
#
# Created by: PyQt6 UI code generator 6.9.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_appSelectDialog(object):
    def setupUi(self, appSelectDialog):
        appSelectDialog.setObjectName("appSelectDialog")
        appSelectDialog.resize(225, 200)
        self.verticalLayout = QtWidgets.QVBoxLayout(appSelectDialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(parent=appSelectDialog)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.wsjtxRadioButton = QtWidgets.QRadioButton(parent=appSelectDialog)
        self.wsjtxRadioButton.setObjectName("wsjtxRadioButton")
        self.verticalLayout.addWidget(self.wsjtxRadioButton)
        self.js8callRadioButton = QtWidgets.QRadioButton(parent=appSelectDialog)
        self.js8callRadioButton.setObjectName("js8callRadioButton")
        self.verticalLayout.addWidget(self.js8callRadioButton)
        self.fldigiRadioButton = QtWidgets.QRadioButton(parent=appSelectDialog)
        self.fldigiRadioButton.setObjectName("fldigiRadioButton")
        self.verticalLayout.addWidget(self.fldigiRadioButton)
        self.otherRadioButton = QtWidgets.QRadioButton(parent=appSelectDialog)
        self.otherRadioButton.setChecked(True)
        self.otherRadioButton.setObjectName("otherRadioButton")
        self.verticalLayout.addWidget(self.otherRadioButton)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        self.buttonBox = QtWidgets.QDialogButtonBox(parent=appSelectDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Orientation.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.StandardButton.Cancel|QtWidgets.QDialogButtonBox.StandardButton.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(appSelectDialog)
        self.buttonBox.accepted.connect(appSelectDialog.accept) # type: ignore
        self.buttonBox.rejected.connect(appSelectDialog.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(appSelectDialog)

    def retranslateUi(self, appSelectDialog):
        _translate = QtCore.QCoreApplication.translate
        self.label.setText(_translate("appSelectDialog", "Select the application"))
        self.wsjtxRadioButton.setText(_translate("appSelectDialog", "WSJT-X"))
        self.js8callRadioButton.setText(_translate("appSelectDialog", "JS8Call"))
        self.fldigiRadioButton.setText(_translate("appSelectDialog", "fldigi"))
        self.otherRadioButton.setText(_translate("appSelectDialog", "Other"))
