# Form implementation generated from reading ui file 'ContestDlg.ui'
#
# Created by: PyQt6 UI code generator 6.9.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_ContestDialog(object):
    def setupUi(self, ContestDialog):
        ContestDialog.setObjectName("ContestDialog")
        ContestDialog.resize(554, 516)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(ContestDialog)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.label = QtWidgets.QLabel(parent=ContestDialog)
        self.label.setObjectName("label")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label)
        self.contestComboBox = QtWidgets.QComboBox(parent=ContestDialog)
        self.contestComboBox.setObjectName("contestComboBox")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.contestComboBox)
        self.label_2 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_2.setObjectName("label_2")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_2)
        self.bandComboBox = QtWidgets.QComboBox(parent=ContestDialog)
        self.bandComboBox.setObjectName("bandComboBox")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.bandComboBox)
        self.label_3 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_3.setObjectName("label_3")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_3)
        self.fromDateEdit = QtWidgets.QDateEdit(parent=ContestDialog)
        self.fromDateEdit.setMinimumDate(QtCore.QDate(1900, 1, 1))
        self.fromDateEdit.setCurrentSection(QtWidgets.QDateTimeEdit.Section.YearSection)
        self.fromDateEdit.setCalendarPopup(True)
        self.fromDateEdit.setObjectName("fromDateEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.fromDateEdit)
        self.label_4 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_4.setObjectName("label_4")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_4)
        self.toDateEdit = QtWidgets.QDateEdit(parent=ContestDialog)
        self.toDateEdit.setCalendarPopup(True)
        self.toDateEdit.setObjectName("toDateEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.ItemRole.FieldRole, self.toDateEdit)
        self.line_2 = QtWidgets.QFrame(parent=ContestDialog)
        self.line_2.setFrameShape(QtWidgets.QFrame.Shape.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_2.setObjectName("line_2")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.ItemRole.FieldRole, self.line_2)
        self.label_6 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_6.setObjectName("label_6")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_6)
        self.callLineEdit = QtWidgets.QLineEdit(parent=ContestDialog)
        self.callLineEdit.setObjectName("callLineEdit")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.ItemRole.FieldRole, self.callLineEdit)
        self.label_11 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_11.setObjectName("label_11")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_11)
        self.locatorLineEdit = QtWidgets.QLineEdit(parent=ContestDialog)
        self.locatorLineEdit.setObjectName("locatorLineEdit")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.ItemRole.FieldRole, self.locatorLineEdit)
        self.label_7 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_7.setObjectName("label_7")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_7)
        self.nameLineEdit = QtWidgets.QLineEdit(parent=ContestDialog)
        self.nameLineEdit.setObjectName("nameLineEdit")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.ItemRole.FieldRole, self.nameLineEdit)
        self.label_10 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_10.setObjectName("label_10")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_10)
        self.emailLineEdit = QtWidgets.QLineEdit(parent=ContestDialog)
        self.emailLineEdit.setObjectName("emailLineEdit")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.ItemRole.FieldRole, self.emailLineEdit)
        self.label_5 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_5.setObjectName("label_5")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_5)
        self.streetLineEdit = QtWidgets.QLineEdit(parent=ContestDialog)
        self.streetLineEdit.setObjectName("streetLineEdit")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.ItemRole.FieldRole, self.streetLineEdit)
        self.label_8 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_8.setObjectName("label_8")
        self.formLayout.setWidget(11, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_8)
        self.cityLineEdit = QtWidgets.QLineEdit(parent=ContestDialog)
        self.cityLineEdit.setObjectName("cityLineEdit")
        self.formLayout.setWidget(11, QtWidgets.QFormLayout.ItemRole.FieldRole, self.cityLineEdit)
        self.specificLabel = QtWidgets.QLabel(parent=ContestDialog)
        self.specificLabel.setObjectName("specificLabel")
        self.formLayout.setWidget(13, QtWidgets.QFormLayout.ItemRole.LabelRole, self.specificLabel)
        self.specificLineEdit = QtWidgets.QLineEdit(parent=ContestDialog)
        self.specificLineEdit.setObjectName("specificLineEdit")
        self.formLayout.setWidget(13, QtWidgets.QFormLayout.ItemRole.FieldRole, self.specificLineEdit)
        self.label_9 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_9.setObjectName("label_9")
        self.formLayout.setWidget(14, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_9)
        self.clubLineEdit = QtWidgets.QLineEdit(parent=ContestDialog)
        self.clubLineEdit.setObjectName("clubLineEdit")
        self.formLayout.setWidget(14, QtWidgets.QFormLayout.ItemRole.FieldRole, self.clubLineEdit)
        self.label_15 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_15.setObjectName("label_15")
        self.formLayout.setWidget(16, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_15)
        self.label_13 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_13.setObjectName("label_13")
        self.formLayout.setWidget(18, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_13)
        self.label_12 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_12.setObjectName("label_12")
        self.formLayout.setWidget(19, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_12)
        self.opComboBox = QtWidgets.QComboBox(parent=ContestDialog)
        self.opComboBox.setObjectName("opComboBox")
        self.formLayout.setWidget(16, QtWidgets.QFormLayout.ItemRole.FieldRole, self.opComboBox)
        self.powerComboBox = QtWidgets.QComboBox(parent=ContestDialog)
        self.powerComboBox.setObjectName("powerComboBox")
        self.formLayout.setWidget(18, QtWidgets.QFormLayout.ItemRole.FieldRole, self.powerComboBox)
        self.modeComboBox = QtWidgets.QComboBox(parent=ContestDialog)
        self.modeComboBox.setObjectName("modeComboBox")
        self.formLayout.setWidget(19, QtWidgets.QFormLayout.ItemRole.FieldRole, self.modeComboBox)
        self.line_3 = QtWidgets.QFrame(parent=ContestDialog)
        self.line_3.setFrameShape(QtWidgets.QFrame.Shape.HLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_3.setObjectName("line_3")
        self.formLayout.setWidget(15, QtWidgets.QFormLayout.ItemRole.FieldRole, self.line_3)
        self.label_23 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_23.setObjectName("label_23")
        self.formLayout.setWidget(10, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_23)
        self.zipLineEdit = QtWidgets.QLineEdit(parent=ContestDialog)
        self.zipLineEdit.setObjectName("zipLineEdit")
        self.formLayout.setWidget(10, QtWidgets.QFormLayout.ItemRole.FieldRole, self.zipLineEdit)
        self.label_24 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_24.setObjectName("label_24")
        self.formLayout.setWidget(12, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_24)
        self.countryLineEdit = QtWidgets.QLineEdit(parent=ContestDialog)
        self.countryLineEdit.setObjectName("countryLineEdit")
        self.formLayout.setWidget(12, QtWidgets.QFormLayout.ItemRole.FieldRole, self.countryLineEdit)
        self.operatorsLineEdit = QtWidgets.QLineEdit(parent=ContestDialog)
        self.operatorsLineEdit.setEnabled(False)
        self.operatorsLineEdit.setObjectName("operatorsLineEdit")
        self.formLayout.setWidget(17, QtWidgets.QFormLayout.ItemRole.FieldRole, self.operatorsLineEdit)
        self.label_25 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_25.setObjectName("label_25")
        self.formLayout.setWidget(17, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_25)
        self.verticalLayout_2.addLayout(self.formLayout)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout_2.addItem(spacerItem)
        self.horizontalLayout_3.addLayout(self.verticalLayout_2)
        self.line_1 = QtWidgets.QFrame(parent=ContestDialog)
        self.line_1.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_1.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_1.setObjectName("line_1")
        self.horizontalLayout_3.addWidget(self.line_1)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.ediGroupBox = QtWidgets.QGroupBox(parent=ContestDialog)
        self.ediGroupBox.setEnabled(False)
        self.ediGroupBox.setObjectName("ediGroupBox")
        self.formLayout_3 = QtWidgets.QFormLayout(self.ediGroupBox)
        self.formLayout_3.setObjectName("formLayout_3")
        self.antennaLineEdit = QtWidgets.QLineEdit(parent=self.ediGroupBox)
        self.antennaLineEdit.setObjectName("antennaLineEdit")
        self.formLayout_3.setWidget(5, QtWidgets.QFormLayout.ItemRole.FieldRole, self.antennaLineEdit)
        self.rigLineEdit = QtWidgets.QLineEdit(parent=self.ediGroupBox)
        self.rigLineEdit.setObjectName("rigLineEdit")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.ItemRole.FieldRole, self.rigLineEdit)
        self.label_19 = QtWidgets.QLabel(parent=self.ediGroupBox)
        self.label_19.setObjectName("label_19")
        self.formLayout_3.setWidget(5, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_19)
        self.powerSpinBox = QtWidgets.QSpinBox(parent=self.ediGroupBox)
        self.powerSpinBox.setMaximum(999)
        self.powerSpinBox.setObjectName("powerSpinBox")
        self.formLayout_3.setWidget(3, QtWidgets.QFormLayout.ItemRole.FieldRole, self.powerSpinBox)
        self.label_18 = QtWidgets.QLabel(parent=self.ediGroupBox)
        self.label_18.setObjectName("label_18")
        self.formLayout_3.setWidget(3, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_18)
        self.label_20 = QtWidgets.QLabel(parent=self.ediGroupBox)
        self.label_20.setObjectName("label_20")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_20)
        self.qthLineEdit = QtWidgets.QLineEdit(parent=self.ediGroupBox)
        self.qthLineEdit.setObjectName("qthLineEdit")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.ItemRole.FieldRole, self.qthLineEdit)
        self.label_21 = QtWidgets.QLabel(parent=self.ediGroupBox)
        self.label_21.setObjectName("label_21")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_21)
        self.label_16 = QtWidgets.QLabel(parent=self.ediGroupBox)
        self.label_16.setObjectName("label_16")
        self.formLayout_3.setWidget(6, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_16)
        self.antAboveGroundSpinBox = QtWidgets.QSpinBox(parent=self.ediGroupBox)
        self.antAboveGroundSpinBox.setMinimum(-1)
        self.antAboveGroundSpinBox.setMaximum(499)
        self.antAboveGroundSpinBox.setStepType(QtWidgets.QAbstractSpinBox.StepType.AdaptiveDecimalStepType)
        self.antAboveGroundSpinBox.setProperty("value", -1)
        self.antAboveGroundSpinBox.setObjectName("antAboveGroundSpinBox")
        self.formLayout_3.setWidget(6, QtWidgets.QFormLayout.ItemRole.FieldRole, self.antAboveGroundSpinBox)
        self.label_17 = QtWidgets.QLabel(parent=self.ediGroupBox)
        self.label_17.setObjectName("label_17")
        self.formLayout_3.setWidget(7, QtWidgets.QFormLayout.ItemRole.LabelRole, self.label_17)
        self.antAboveSeaSpinBox = QtWidgets.QSpinBox(parent=self.ediGroupBox)
        self.antAboveSeaSpinBox.setMinimum(-1)
        self.antAboveSeaSpinBox.setMaximum(9999)
        self.antAboveSeaSpinBox.setStepType(QtWidgets.QAbstractSpinBox.StepType.AdaptiveDecimalStepType)
        self.antAboveSeaSpinBox.setProperty("value", -1)
        self.antAboveSeaSpinBox.setObjectName("antAboveSeaSpinBox")
        self.formLayout_3.setWidget(7, QtWidgets.QFormLayout.ItemRole.FieldRole, self.antAboveSeaSpinBox)
        self.line = QtWidgets.QFrame(parent=self.ediGroupBox)
        self.line.setFrameShape(QtWidgets.QFrame.Shape.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line.setObjectName("line")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.ItemRole.FieldRole, self.line)
        self.line_4 = QtWidgets.QFrame(parent=self.ediGroupBox)
        self.line_4.setFrameShape(QtWidgets.QFrame.Shape.HLine)
        self.line_4.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_4.setObjectName("line_4")
        self.formLayout_3.setWidget(4, QtWidgets.QFormLayout.ItemRole.FieldRole, self.line_4)
        self.verticalLayout.addWidget(self.ediGroupBox)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout.addItem(spacerItem1)
        self.label_14 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_14.setObjectName("label_14")
        self.verticalLayout.addWidget(self.label_14)
        self.soapPlainTextEdit = QtWidgets.QPlainTextEdit(parent=ContestDialog)
        self.soapPlainTextEdit.setMinimumSize(QtCore.QSize(0, 40))
        self.soapPlainTextEdit.setMaximumSize(QtCore.QSize(16777215, 60))
        self.soapPlainTextEdit.setObjectName("soapPlainTextEdit")
        self.verticalLayout.addWidget(self.soapPlainTextEdit)
        spacerItem2 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Minimum)
        self.verticalLayout.addItem(spacerItem2)
        self.label_22 = QtWidgets.QLabel(parent=ContestDialog)
        self.label_22.setObjectName("label_22")
        self.verticalLayout.addWidget(self.label_22)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setSpacing(0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.exportPathLineEdit = QtWidgets.QLineEdit(parent=ContestDialog)
        self.exportPathLineEdit.setObjectName("exportPathLineEdit")
        self.horizontalLayout_2.addWidget(self.exportPathLineEdit)
        self.choosePathToolButton = QtWidgets.QToolButton(parent=ContestDialog)
        self.choosePathToolButton.setObjectName("choosePathToolButton")
        self.horizontalLayout_2.addWidget(self.choosePathToolButton)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        spacerItem3 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Minimum)
        self.verticalLayout.addItem(spacerItem3)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem4)
        self.exportPushButton = QtWidgets.QPushButton(parent=ContestDialog)
        self.exportPushButton.setEnabled(False)
        self.exportPushButton.setObjectName("exportPushButton")
        self.horizontalLayout.addWidget(self.exportPushButton)
        self.cancelPushButton = QtWidgets.QPushButton(parent=ContestDialog)
        self.cancelPushButton.setObjectName("cancelPushButton")
        self.horizontalLayout.addWidget(self.cancelPushButton)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_3.addLayout(self.verticalLayout)

        self.retranslateUi(ContestDialog)
        self.exportPushButton.clicked.connect(ContestDialog.accept) # type: ignore
        self.cancelPushButton.clicked.connect(ContestDialog.reject) # type: ignore
        self.contestComboBox.currentTextChanged['QString'].connect(ContestDialog.contestChanged) # type: ignore
        self.fromDateEdit.dateChanged['QDate'].connect(ContestDialog.fromDateChanged) # type: ignore
        self.choosePathToolButton.clicked.connect(ContestDialog.choosePath) # type: ignore
        self.callLineEdit.textChanged['QString'].connect(ContestDialog.callChanged) # type: ignore
        self.locatorLineEdit.textChanged['QString'].connect(ContestDialog.locatorChanged) # type: ignore
        self.nameLineEdit.textChanged['QString'].connect(ContestDialog.nameChanged) # type: ignore
        self.cityLineEdit.textChanged['QString'].connect(ContestDialog.cityChanged) # type: ignore
        self.streetLineEdit.textChanged['QString'].connect(ContestDialog.streetChanged) # type: ignore
        self.emailLineEdit.textChanged['QString'].connect(ContestDialog.emailChanged) # type: ignore
        self.clubLineEdit.textChanged['QString'].connect(ContestDialog.clubChanged) # type: ignore
        self.specificLineEdit.textChanged['QString'].connect(ContestDialog.specificChanged) # type: ignore
        self.zipLineEdit.textChanged['QString'].connect(ContestDialog.zipChanged) # type: ignore
        self.opComboBox.currentTextChanged['QString'].connect(ContestDialog.operatorChanged) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(ContestDialog)

    def retranslateUi(self, ContestDialog):
        _translate = QtCore.QCoreApplication.translate
        ContestDialog.setWindowTitle(_translate("ContestDialog", "Contest Export"))
        self.label.setText(_translate("ContestDialog", "Contest"))
        self.label_2.setText(_translate("ContestDialog", "Band"))
        self.label_3.setText(_translate("ContestDialog", "Date from"))
        self.fromDateEdit.setDisplayFormat(_translate("ContestDialog", "yyyy-MM-dd"))
        self.label_4.setText(_translate("ContestDialog", "Date to"))
        self.toDateEdit.setDisplayFormat(_translate("ContestDialog", "yyyy-MM-dd"))
        self.label_6.setText(_translate("ContestDialog", "Callsign"))
        self.callLineEdit.setPlaceholderText(_translate("ContestDialog", "DX1XX"))
        self.label_11.setText(_translate("ContestDialog", "Locator"))
        self.locatorLineEdit.setPlaceholderText(_translate("ContestDialog", "AA11aa"))
        self.label_7.setText(_translate("ContestDialog", "Fullname"))
        self.nameLineEdit.setPlaceholderText(_translate("ContestDialog", "Max Example"))
        self.label_10.setText(_translate("ContestDialog", "eMail"))
        self.emailLineEdit.setPlaceholderText(_translate("ContestDialog", "dx1xx@darc.de"))
        self.label_5.setText(_translate("ContestDialog", "Street"))
        self.streetLineEdit.setPlaceholderText(_translate("ContestDialog", "Street 1"))
        self.label_8.setText(_translate("ContestDialog", "City"))
        self.cityLineEdit.setPlaceholderText(_translate("ContestDialog", "Berlin"))
        self.specificLabel.setText(_translate("ContestDialog", "Specific"))
        self.specificLineEdit.setPlaceholderText(_translate("ContestDialog", "Contest specific information"))
        self.label_9.setText(_translate("ContestDialog", "Club"))
        self.clubLineEdit.setPlaceholderText(_translate("ContestDialog", "DARC"))
        self.label_15.setText(_translate("ContestDialog", "Operator"))
        self.label_13.setText(_translate("ContestDialog", "Power"))
        self.label_12.setText(_translate("ContestDialog", "Mode"))
        self.label_23.setText(_translate("ContestDialog", "Zip"))
        self.zipLineEdit.setPlaceholderText(_translate("ContestDialog", "11111"))
        self.label_24.setText(_translate("ContestDialog", "Country"))
        self.countryLineEdit.setPlaceholderText(_translate("ContestDialog", "Deutschland"))
        self.operatorsLineEdit.setPlaceholderText(_translate("ContestDialog", "DX1XX DY1YY DX2XX DY2YY"))
        self.label_25.setText(_translate("ContestDialog", "Operators"))
        self.ediGroupBox.setTitle(_translate("ContestDialog", "Additional EDI data"))
        self.label_19.setText(_translate("ContestDialog", "Antenna"))
        self.powerSpinBox.setSpecialValueText(_translate("ContestDialog", "n.a."))
        self.powerSpinBox.setSuffix(_translate("ContestDialog", " W"))
        self.label_18.setText(_translate("ContestDialog", "Power"))
        self.label_20.setText(_translate("ContestDialog", "Rig"))
        self.label_21.setText(_translate("ContestDialog", "Contest QTH"))
        self.label_16.setText(_translate("ContestDialog", "Ant. above ground"))
        self.antAboveGroundSpinBox.setSpecialValueText(_translate("ContestDialog", "n.a."))
        self.antAboveGroundSpinBox.setSuffix(_translate("ContestDialog", " m"))
        self.label_17.setText(_translate("ContestDialog", "Ant. above sea lvl."))
        self.antAboveSeaSpinBox.setSpecialValueText(_translate("ContestDialog", "n.a."))
        self.antAboveSeaSpinBox.setSuffix(_translate("ContestDialog", " m"))
        self.label_14.setText(_translate("ContestDialog", "Soapbox"))
        self.soapPlainTextEdit.setPlaceholderText(_translate("ContestDialog", "Extra information"))
        self.label_22.setText(_translate("ContestDialog", "Export path"))
        self.exportPathLineEdit.setPlaceholderText(_translate("ContestDialog", "Export path"))
        self.choosePathToolButton.setText(_translate("ContestDialog", "..."))
        self.exportPushButton.setText(_translate("ContestDialog", "Export"))
        self.cancelPushButton.setText(_translate("ContestDialog", "Cancel"))
