# Form implementation generated from reading ui file 'ListEdit.ui'
#
# Created by: PyQt6 UI code generator 6.9.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_ListEditForm(object):
    def setupUi(self, ListEditForm):
        ListEditForm.setObjectName("ListEditForm")
        ListEditForm.resize(155, 180)
        self.verticalLayout = QtWidgets.QVBoxLayout(ListEditForm)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(parent=ListEditForm)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.listWidget = QtWidgets.QListWidget(parent=ListEditForm)
        self.listWidget.setEditTriggers(QtWidgets.QAbstractItemView.EditTrigger.AnyKeyPressed|QtWidgets.QAbstractItemView.EditTrigger.DoubleClicked|QtWidgets.QAbstractItemView.EditTrigger.EditKeyPressed)
        self.listWidget.setAlternatingRowColors(True)
        self.listWidget.setObjectName("listWidget")
        self.verticalLayout.addWidget(self.listWidget)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.addPushButton = QtWidgets.QPushButton(parent=ListEditForm)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap("icons:edit_add.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.addPushButton.setIcon(icon)
        self.addPushButton.setObjectName("addPushButton")
        self.horizontalLayout.addWidget(self.addPushButton)
        self.delPushButton = QtWidgets.QPushButton(parent=ListEditForm)
        self.delPushButton.setEnabled(False)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap("icons:edit_remove.png"), QtGui.QIcon.Mode.Normal, QtGui.QIcon.State.Off)
        self.delPushButton.setIcon(icon1)
        self.delPushButton.setObjectName("delPushButton")
        self.horizontalLayout.addWidget(self.delPushButton)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.verticalLayout.addLayout(self.horizontalLayout)

        self.retranslateUi(ListEditForm)
        self.addPushButton.clicked.connect(ListEditForm.addEmptyItem) # type: ignore
        self.delPushButton.clicked.connect(ListEditForm.removeSelectedItem) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(ListEditForm)

    def retranslateUi(self, ListEditForm):
        _translate = QtCore.QCoreApplication.translate
        ListEditForm.setWindowTitle(_translate("ListEditForm", "Form"))
        self.label.setText(_translate("ListEditForm", "Label"))
