# Form implementation generated from reading ui file 'DxSpots.ui'
#
# Created by: PyQt6 UI code generator 6.9.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_DxSpotsForm(object):
    def setupUi(self, DxSpotsForm):
        DxSpotsForm.setObjectName("DxSpotsForm")
        DxSpotsForm.resize(501, 476)
        self.verticalLayout = QtWidgets.QVBoxLayout(DxSpotsForm)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(parent=DxSpotsForm)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.nrSpotsSpinBox = QtWidgets.QSpinBox(parent=DxSpotsForm)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.nrSpotsSpinBox.sizePolicy().hasHeightForWidth())
        self.nrSpotsSpinBox.setSizePolicy(sizePolicy)
        self.nrSpotsSpinBox.setMinimum(10)
        self.nrSpotsSpinBox.setMaximum(200)
        self.nrSpotsSpinBox.setSingleStep(10)
        self.nrSpotsSpinBox.setProperty("value", 50)
        self.nrSpotsSpinBox.setObjectName("nrSpotsSpinBox")
        self.horizontalLayout.addWidget(self.nrSpotsSpinBox)
        spacerItem = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.label_2 = QtWidgets.QLabel(parent=DxSpotsForm)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_2.sizePolicy().hasHeightForWidth())
        self.label_2.setSizePolicy(sizePolicy)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout.addWidget(self.label_2)
        self.bandComboBox = QtWidgets.QComboBox(parent=DxSpotsForm)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bandComboBox.sizePolicy().hasHeightForWidth())
        self.bandComboBox.setSizePolicy(sizePolicy)
        self.bandComboBox.setObjectName("bandComboBox")
        self.horizontalLayout.addWidget(self.bandComboBox)
        self.line = QtWidgets.QFrame(parent=DxSpotsForm)
        self.line.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout.addWidget(self.line)
        self.label_3 = QtWidgets.QLabel(parent=DxSpotsForm)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout.addWidget(self.label_3)
        self.spContComboBox = QtWidgets.QComboBox(parent=DxSpotsForm)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.spContComboBox.sizePolicy().hasHeightForWidth())
        self.spContComboBox.setSizePolicy(sizePolicy)
        self.spContComboBox.setObjectName("spContComboBox")
        self.horizontalLayout.addWidget(self.spContComboBox)
        spacerItem1 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.startPushButton = QtWidgets.QPushButton(parent=DxSpotsForm)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Fixed, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.startPushButton.sizePolicy().hasHeightForWidth())
        self.startPushButton.setSizePolicy(sizePolicy)
        self.startPushButton.setCheckable(True)
        self.startPushButton.setObjectName("startPushButton")
        self.horizontalLayout.addWidget(self.startPushButton)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.tableView = QtWidgets.QTableView(parent=DxSpotsForm)
        self.tableView.setEditTriggers(QtWidgets.QAbstractItemView.EditTrigger.NoEditTriggers)
        self.tableView.setSelectionMode(QtWidgets.QAbstractItemView.SelectionMode.SingleSelection)
        self.tableView.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectionBehavior.SelectRows)
        self.tableView.setObjectName("tableView")
        self.tableView.verticalHeader().setVisible(False)
        self.verticalLayout.addWidget(self.tableView)

        self.retranslateUi(DxSpotsForm)
        self.startPushButton.toggled['bool'].connect(DxSpotsForm.control) # type: ignore
        self.bandComboBox.currentTextChanged['QString'].connect(DxSpotsForm.bandChanged) # type: ignore
        self.tableView.doubleClicked['QModelIndex'].connect(DxSpotsForm.selectSpot) # type: ignore
        self.spContComboBox.currentTextChanged['QString'].connect(DxSpotsForm.spContChanged) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(DxSpotsForm)

    def retranslateUi(self, DxSpotsForm):
        _translate = QtCore.QCoreApplication.translate
        DxSpotsForm.setWindowTitle(_translate("DxSpotsForm", "Form"))
        self.label.setText(_translate("DxSpotsForm", "Keep spots"))
        self.label_2.setText(_translate("DxSpotsForm", "Band"))
        self.label_3.setText(_translate("DxSpotsForm", "Sp. Cnt."))
        self.startPushButton.setText(_translate("DxSpotsForm", "Start"))
