# Form implementation generated from reading ui file 'SelectWidget.ui'
#
# Created by: PyQt6 UI code generator 6.9.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_SelectWidget(object):
    def setupUi(self, SelectWidget):
        SelectWidget.setObjectName("SelectWidget")
        SelectWidget.resize(300, 150)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(SelectWidget.sizePolicy().hasHeightForWidth())
        SelectWidget.setSizePolicy(sizePolicy)
        self.horizontalLayout = QtWidgets.QHBoxLayout(SelectWidget)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(6)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.labelEnabled = QtWidgets.QLabel(parent=SelectWidget)
        self.labelEnabled.setObjectName("labelEnabled")
        self.verticalLayout_3.addWidget(self.labelEnabled)
        self.enabledListWidget = QtWidgets.QListWidget(parent=SelectWidget)
        self.enabledListWidget.setObjectName("enabledListWidget")
        self.verticalLayout_3.addWidget(self.enabledListWidget)
        self.horizontalLayout.addLayout(self.verticalLayout_3)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSpacing(6)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label = QtWidgets.QLabel(parent=SelectWidget)
        self.label.setText("")
        self.label.setObjectName("label")
        self.verticalLayout_2.addWidget(self.label)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout_2.addItem(spacerItem)
        self.disablePushButton = QtWidgets.QPushButton(parent=SelectWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.disablePushButton.sizePolicy().hasHeightForWidth())
        self.disablePushButton.setSizePolicy(sizePolicy)
        self.disablePushButton.setMaximumSize(QtCore.QSize(20, 16777215))
        self.disablePushButton.setObjectName("disablePushButton")
        self.verticalLayout_2.addWidget(self.disablePushButton)
        self.enablePushButton = QtWidgets.QPushButton(parent=SelectWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.enablePushButton.sizePolicy().hasHeightForWidth())
        self.enablePushButton.setSizePolicy(sizePolicy)
        self.enablePushButton.setMaximumSize(QtCore.QSize(20, 16777215))
        self.enablePushButton.setObjectName("enablePushButton")
        self.verticalLayout_2.addWidget(self.enablePushButton)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Policy.Minimum, QtWidgets.QSizePolicy.Policy.Expanding)
        self.verticalLayout_2.addItem(spacerItem1)
        self.horizontalLayout.addLayout(self.verticalLayout_2)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.labelDisabled = QtWidgets.QLabel(parent=SelectWidget)
        self.labelDisabled.setObjectName("labelDisabled")
        self.verticalLayout_4.addWidget(self.labelDisabled)
        self.disabledListWidget = QtWidgets.QListWidget(parent=SelectWidget)
        self.disabledListWidget.setObjectName("disabledListWidget")
        self.verticalLayout_4.addWidget(self.disabledListWidget)
        self.horizontalLayout.addLayout(self.verticalLayout_4)

        self.retranslateUi(SelectWidget)
        self.disablePushButton.clicked.connect(SelectWidget.disableItem) # type: ignore
        self.enablePushButton.clicked.connect(SelectWidget.enableItem) # type: ignore
        self.disabledListWidget.itemDoubleClicked['QListWidgetItem*'].connect(SelectWidget.enableItem) # type: ignore
        self.enabledListWidget.itemDoubleClicked['QListWidgetItem*'].connect(SelectWidget.disableItem) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(SelectWidget)

    def retranslateUi(self, SelectWidget):
        _translate = QtCore.QCoreApplication.translate
        SelectWidget.setWindowTitle(_translate("SelectWidget", "Form"))
        self.labelEnabled.setText(_translate("SelectWidget", "Items enabled"))
        self.disablePushButton.setText(_translate("SelectWidget", ">"))
        self.enablePushButton.setText(_translate("SelectWidget", "<"))
        self.labelDisabled.setText(_translate("SelectWidget", "Items disabled"))
