# Form implementation generated from reading ui file 'ContestStatistics.ui'
#
# Created by: PyQt6 UI code generator 6.9.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic6 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt6 import QtCore, QtGui, QtWidgets


class Ui_ContestStatistics(object):
    def setupUi(self, ContestStatistics):
        ContestStatistics.setObjectName("ContestStatistics")
        ContestStatistics.resize(350, 370)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(ContestStatistics)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.label_3 = QtWidgets.QLabel(parent=ContestStatistics)
        self.label_3.setObjectName("label_3")
        self.verticalLayout_3.addWidget(self.label_3)
        self.contestComboBox = QtWidgets.QComboBox(parent=ContestStatistics)
        self.contestComboBox.setObjectName("contestComboBox")
        self.verticalLayout_3.addWidget(self.contestComboBox)
        self.horizontalLayout.addLayout(self.verticalLayout_3)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(parent=ContestStatistics)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.fromDateEdit = QtWidgets.QDateEdit(parent=ContestStatistics)
        self.fromDateEdit.setCalendarPopup(True)
        self.fromDateEdit.setObjectName("fromDateEdit")
        self.verticalLayout.addWidget(self.fromDateEdit)
        self.horizontalLayout.addLayout(self.verticalLayout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_2 = QtWidgets.QLabel(parent=ContestStatistics)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_2.addWidget(self.label_2)
        self.toDateEdit = QtWidgets.QDateEdit(parent=ContestStatistics)
        self.toDateEdit.setEnabled(False)
        self.toDateEdit.setCalendarPopup(True)
        self.toDateEdit.setObjectName("toDateEdit")
        self.verticalLayout_2.addWidget(self.toDateEdit)
        self.horizontalLayout.addLayout(self.verticalLayout_2)
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.specificLabel = QtWidgets.QLabel(parent=ContestStatistics)
        self.specificLabel.setEnabled(False)
        self.specificLabel.setObjectName("specificLabel")
        self.verticalLayout_5.addWidget(self.specificLabel)
        self.specificLineEdit = QtWidgets.QLineEdit(parent=ContestStatistics)
        self.specificLineEdit.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.MinimumExpanding, QtWidgets.QSizePolicy.Policy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.specificLineEdit.sizePolicy().hasHeightForWidth())
        self.specificLineEdit.setSizePolicy(sizePolicy)
        self.specificLineEdit.setMinimumSize(QtCore.QSize(75, 0))
        self.specificLineEdit.setObjectName("specificLineEdit")
        self.verticalLayout_5.addWidget(self.specificLineEdit)
        self.horizontalLayout.addLayout(self.verticalLayout_5)
        self.verticalLayout_4.addLayout(self.horizontalLayout)
        self.tableView = QtWidgets.QTableView(parent=ContestStatistics)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tableView.sizePolicy().hasHeightForWidth())
        self.tableView.setSizePolicy(sizePolicy)
        self.tableView.setMinimumSize(QtCore.QSize(300, 100))
        self.tableView.setEditTriggers(QtWidgets.QAbstractItemView.EditTrigger.NoEditTriggers)
        self.tableView.setSelectionMode(QtWidgets.QAbstractItemView.SelectionMode.NoSelection)
        self.tableView.setCornerButtonEnabled(False)
        self.tableView.setObjectName("tableView")
        self.tableView.horizontalHeader().setHighlightSections(False)
        self.tableView.verticalHeader().setHighlightSections(False)
        self.verticalLayout_4.addWidget(self.tableView)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.multisLabel = QtWidgets.QLabel(parent=ContestStatistics)
        self.multisLabel.setText("Multis")
        self.multisLabel.setObjectName("multisLabel")
        self.gridLayout.addWidget(self.multisLabel, 0, 0, 1, 1)
        self.multisPlainTextEdit = QtWidgets.QPlainTextEdit(parent=ContestStatistics)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.multisPlainTextEdit.sizePolicy().hasHeightForWidth())
        self.multisPlainTextEdit.setSizePolicy(sizePolicy)
        self.multisPlainTextEdit.setMinimumSize(QtCore.QSize(0, 25))
        self.multisPlainTextEdit.setMaximumSize(QtCore.QSize(16777215, 60))
        self.multisPlainTextEdit.setUndoRedoEnabled(False)
        self.multisPlainTextEdit.setLineWrapMode(QtWidgets.QPlainTextEdit.LineWrapMode.WidgetWidth)
        self.multisPlainTextEdit.setReadOnly(True)
        self.multisPlainTextEdit.setObjectName("multisPlainTextEdit")
        self.gridLayout.addWidget(self.multisPlainTextEdit, 0, 1, 1, 1)
        self.multis2Label = QtWidgets.QLabel(parent=ContestStatistics)
        self.multis2Label.setText("Multis 2")
        self.multis2Label.setObjectName("multis2Label")
        self.gridLayout.addWidget(self.multis2Label, 1, 0, 1, 1)
        self.multis2PlainTextEdit = QtWidgets.QPlainTextEdit(parent=ContestStatistics)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.multis2PlainTextEdit.sizePolicy().hasHeightForWidth())
        self.multis2PlainTextEdit.setSizePolicy(sizePolicy)
        self.multis2PlainTextEdit.setMinimumSize(QtCore.QSize(0, 25))
        self.multis2PlainTextEdit.setMaximumSize(QtCore.QSize(16777215, 60))
        self.multis2PlainTextEdit.setUndoRedoEnabled(False)
        self.multis2PlainTextEdit.setReadOnly(True)
        self.multis2PlainTextEdit.setObjectName("multis2PlainTextEdit")
        self.gridLayout.addWidget(self.multis2PlainTextEdit, 1, 1, 1, 1)
        self.verticalLayout_4.addLayout(self.gridLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_6 = QtWidgets.QLabel(parent=ContestStatistics)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_2.addWidget(self.label_6)
        self.infosLabel = QtWidgets.QLabel(parent=ContestStatistics)
        self.infosLabel.setObjectName("infosLabel")
        self.horizontalLayout_2.addWidget(self.infosLabel)
        self.line = QtWidgets.QFrame(parent=ContestStatistics)
        self.line.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_2.addWidget(self.line)
        self.label_9 = QtWidgets.QLabel(parent=ContestStatistics)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_2.addWidget(self.label_9)
        self.warningsLabel = QtWidgets.QLabel(parent=ContestStatistics)
        self.warningsLabel.setObjectName("warningsLabel")
        self.horizontalLayout_2.addWidget(self.warningsLabel)
        self.line_2 = QtWidgets.QFrame(parent=ContestStatistics)
        self.line_2.setFrameShape(QtWidgets.QFrame.Shape.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Shadow.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout_2.addWidget(self.line_2)
        self.label_7 = QtWidgets.QLabel(parent=ContestStatistics)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_2.addWidget(self.label_7)
        self.errorsLabel = QtWidgets.QLabel(parent=ContestStatistics)
        self.errorsLabel.setObjectName("errorsLabel")
        self.horizontalLayout_2.addWidget(self.errorsLabel)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Policy.Expanding, QtWidgets.QSizePolicy.Policy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.verticalLayout_4.addLayout(self.horizontalLayout_2)
        self.verticalLayout_4.setStretch(1, 3)
        self.verticalLayout_4.setStretch(2, 1)

        self.retranslateUi(ContestStatistics)
        self.contestComboBox.currentTextChanged['QString'].connect(ContestStatistics.contestChanged) # type: ignore
        self.fromDateEdit.dateChanged['QDate'].connect(ContestStatistics.fromDateChanged) # type: ignore
        self.toDateEdit.dateChanged['QDate'].connect(ContestStatistics.toDateChanged) # type: ignore
        self.specificLineEdit.editingFinished.connect(ContestStatistics.specificChanged) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(ContestStatistics)

    def retranslateUi(self, ContestStatistics):
        _translate = QtCore.QCoreApplication.translate
        ContestStatistics.setWindowTitle(_translate("ContestStatistics", "Contest Statistics"))
        self.label_3.setText(_translate("ContestStatistics", "Contest"))
        self.label.setText(_translate("ContestStatistics", "Date from"))
        self.fromDateEdit.setDisplayFormat(_translate("ContestStatistics", "yyyy-MM-dd"))
        self.label_2.setText(_translate("ContestStatistics", "Date to"))
        self.toDateEdit.setDisplayFormat(_translate("ContestStatistics", "yyyy-MM-dd"))
        self.specificLabel.setText(_translate("ContestStatistics", "Specific"))
        self.label_6.setText(_translate("ContestStatistics", "Infos:"))
        self.infosLabel.setText(_translate("ContestStatistics", "0"))
        self.label_9.setText(_translate("ContestStatistics", "Warnings:"))
        self.warningsLabel.setText(_translate("ContestStatistics", "0"))
        self.label_7.setText(_translate("ContestStatistics", "Errors:"))
        self.errorsLabel.setText(_translate("ContestStatistics", "0"))
